@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -53,12 +47,11 @@ TrackerClient::TrackerClient(TorrentClient *downloader, QObject *parent)
     : QObject(parent), torrentDownloader(downloader)
 {
     length = 0;
-    uploadedBytes = 0;
-    downloadedBytes = 0;
     requestInterval = 5 * 60;
     requestIntervalTimer = -1;
     firstTrackerRequest = true;
     lastTrackerRequest = false;
+    firstSeeding = true;
 
     connect(&http, SIGNAL(done(bool)), this, SLOT(httpRequestDone(bool)));
 }
@@ -77,6 +70,12 @@ void TrackerClient::start(const MetaInfo &info)
     }
 }
 
+void TrackerClient::startSeeding()
+{
+    firstSeeding = true;
+    fetchPeerList();
+}
+
 void TrackerClient::stop()
 {
     lastTrackerRequest = true;
@@ -97,7 +96,13 @@ void TrackerClient::timerEvent(QTimerEvent *event)
 void TrackerClient::fetchPeerList()
 {
     // Prepare connection details
-    QUrl url(metaInfo.announceUrl());
+    QString fullUrl = metaInfo.announceUrl();
+    QUrl url(fullUrl);
+    QString passkey = "?";
+    if (fullUrl.contains("?passkey")) {
+        passkey = metaInfo.announceUrl().mid(fullUrl.indexOf("?passkey"), -1);
+        passkey += "&";
+    }
 
     // Percent encode the hash
     QByteArray infoHash = torrentDownloader->infoHash();
@@ -110,29 +115,39 @@ void TrackerClient::fetchPeerList()
     bool seeding = (torrentDownloader->state() == TorrentClient::Seeding);
     QByteArray query;
     query += url.path().toLatin1();
-    query += "?";
+    query += passkey;
     query += "info_hash=" + encodedSum;
     query += "&peer_id=" + ConnectionManager::instance()->clientId();
     query += "&port=" + QByteArray::number(TorrentServer::instance()->serverPort());
-    query += "&uploaded=" + QByteArray::number(uploadedBytes);
-    query += "&downloaded=" + QByteArray::number(downloadedBytes);
-    query += "&left="+ QByteArray::number(seeding ? 0 : qMax<int>(0, length - downloadedBytes));
     query += "&compact=1";
-    if (seeding) {
+    query += "&uploaded=" + QByteArray::number(torrentDownloader->uploadedBytes());
+
+    if (!firstSeeding) {
+        query += "&downloaded=0";
+        query += "&left=0";
+    } else {
+        query += "&downloaded=" + QByteArray::number(
+            torrentDownloader->downloadedBytes());
+        int left = qMax<int>(0, metaInfo.totalSize() - torrentDownloader->downloadedBytes());
+        query += "&left=" + QByteArray::number(seeding ? 0 : left);
+    }
+
+    if (seeding && firstSeeding) {
         query += "&event=completed";
+        firstSeeding = false;
     } else if (firstTrackerRequest) {
         firstTrackerRequest = false;
         query += "&event=started";
-    } else if (lastTrackerRequest) {
+    } else if(lastTrackerRequest) {
         query += "&event=stopped";
     }
+
     if (!trackerId.isEmpty())
         query += "&trackerid=" + trackerId;
 
     http.setHost(url.host(), url.port() == -1 ? 80 : url.port());
     if (!url.userName().isEmpty())
         http.setUser(url.userName(), url.password());
-
     http.get(query);
 }
 
