@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -84,10 +78,15 @@ public:
               fileName(copy.fileName), cache_enabled(copy.cache_enabled)
         { clear(); }
         inline ~Data() { delete fileEngine; }
-        inline void clear() {
-            fileNames.clear();
+        inline void clearFlags() {
             fileFlags = 0;
             cachedFlags = 0;
+            if (fileEngine)
+                (void)fileEngine->fileFlags(QFSFileEngine::Refresh);
+        }
+        inline void clear() {
+            fileNames.clear();
+            clearFlags();
         }
         mutable QAtomicInt ref;
 
@@ -255,6 +254,8 @@ QFileInfoPrivate::getFileFlags(QAbstractFileEngine::FileFlags request) const
 QDateTime
 &QFileInfoPrivate::getFileTime(QAbstractFileEngine::FileTime request) const
 {
+    if (!data->cache_enabled)
+        data->clearFlags();
     if(request == QAbstractFileEngine::CreationTime) {
         if(data->getCachedFlag(CachedCTime))
             return data->fileTimes[request];
@@ -317,14 +318,14 @@ QDateTime
     transparently; similarly, opening a symlink using QFile
     effectively opens the link's target. For example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 0
 
     On Windows, symlinks (shortcuts) are \c .lnk files. The reported
     size() is that of the symlink (not the link's target), and
     opening a symlink using QFile opens the \c .lnk file. For
     example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 1
 
     Elements of the file's name can be extracted with path() and
     fileName(). The fileName()'s parts can be extracted with
@@ -526,7 +527,7 @@ QFileInfo &QFileInfo::operator=(const QFileInfo &fileinfo)
     path relative to the current directory.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 2
 
     \sa isRelative(), QDir::setCurrent(), QDir::isRelativePath()
 */
@@ -631,6 +632,9 @@ QFileInfo::canonicalFilePath() const
     Returns the file's path absolute path. This doesn't include the
     file name.
 
+    \warning If the QFileInfo object was created with an empty QString,
+              the behavior of this function is undefined.
+
     \sa dir(), filePath(), fileName(), isRelative(), path()
 */
 
@@ -774,7 +778,7 @@ QFileInfo::filePath() const
     Returns the name of the file, excluding the path.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 3
 
     \sa isRelative(), filePath(), baseName(), extension()
 */
@@ -796,7 +800,7 @@ QFileInfo::fileName() const
     path isBundle(). On all other platforms an empty QString is returned.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 4
 
     \sa isBundle(), filePath(), baseName(), extension()
 */
@@ -817,7 +821,7 @@ QFileInfo::bundleName() const
     not including) the \e first '.' character.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 5
 
 
     The base name of a file is computed equally on all platforms, independent
@@ -843,7 +847,7 @@ QFileInfo::baseName() const
     to (but not including) the \e last '.' character.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 6
 
     \sa fileName(), suffix(), completeSuffix(), baseName()
 */
@@ -866,7 +870,7 @@ QFileInfo::completeBaseName() const
     (but not including) the first '.'.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 7
 
     \sa fileName(), suffix(), baseName(), completeBaseName()
 */
@@ -891,7 +895,7 @@ QFileInfo::completeSuffix() const
     including) the last '.'.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 8
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 8
 
     The suffix of a file is computed equally on all platforms, independent of
     file naming conventions (e.g., ".bashrc" on Unix has an empty base name,
@@ -1087,7 +1091,7 @@ QFileInfo::isBundle() const
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 9
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 9
 
     \sa isFile(), isDir(), symLinkTarget()
 */
@@ -1230,7 +1234,7 @@ QFileInfo::groupId() const
     always returns true.
 
     Example:
-    \snippet doc/src/snippets/code/src.corelib.io.qfileinfo.cpp 10
+    \snippet doc/src/snippets/code/src_corelib_io_qfileinfo.cpp 10
 
     \sa isReadable(), isWritable(), isExecutable()
 */
@@ -1401,7 +1405,7 @@ QFileInfo::setCaching(bool enable)
 /*!
     \fn QString QFileInfo::dirPath(bool absPath) const
 
-    Use absoluteFilePath() if the absolute path is wanted (\a absPath
+    Use absolutePath() if the absolute path is wanted (\a absPath
     is true) or path() if it's not necessary (\a absPath is false).
 */
 
