@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -210,7 +204,7 @@ QIODevicePrivate::~QIODevicePrivate()
     Calling these functions from the main, GUI thread, may cause your
     user interface to freeze. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qiodevice.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_io_qiodevice.cpp 0
 
     By subclassing QIODevice, you can provide the same interface to
     your own I/O devices. Subclasses of QIODevice are only required to
@@ -704,7 +698,7 @@ bool QIODevice::reset()
     Subclasses that reimplement this function must call the base
     implementation in order to include the size of QIODevices' buffer. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qiodevice.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_io_qiodevice.cpp 1
 
     \sa bytesToWrite(), readyRead(), isSequential()
 */
@@ -990,7 +984,7 @@ QByteArray QIODevice::readAll()
     For example, the following code reads a line of characters from a
     file:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qiodevice.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_io_qiodevice.cpp 2
 
     The newline character ('\n') is included in the buffer. If a
     newline is not encountered before maxSize - 1 bytes are read, a
@@ -1187,7 +1181,7 @@ qint64 QIODevice::readLineData(char *data, qint64 maxSize)
     Subclasses that reimplement this function must call the base
     implementation in order to include the size of the QIODevice's buffer. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qiodevice.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_io_qiodevice.cpp 3
 
     \sa readyRead(), readLine()
 */
@@ -1389,7 +1383,7 @@ bool QIODevice::getChar(char *c)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qiodevice.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_io_qiodevice.cpp 4
 
     \sa read()
 */
@@ -1411,7 +1405,7 @@ qint64 QIODevice::peek(char *data, qint64 maxSize)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qiodevice.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_io_qiodevice.cpp 5
 
     This function has no way of reporting errors; returning an empty
     QByteArray() can mean either that no data was currently available
