@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -60,13 +54,13 @@ static const int QTEXTSTREAM_BUFFERSIZE = 16384;
     generating text, QTextStream supports formatting options for field
     padding and alignment, and formatting of numbers. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 0
 
     It's also common to use QTextStream to read console input and write
     console output. QTextStream is locale aware, and will automatically decode
     standard input using the correct codec. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 1
 
     Note that you cannot use QTextStream::atEnd(), which returns true when you
     have reached the end of the data stream, with stdin.
@@ -122,7 +116,7 @@ static const int QTEXTSTREAM_BUFFERSIZE = 16384;
     the integer base, thereby disabling the automatic detection, by
     calling setIntegerBase(). Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 2
 
     QTextStream supports many formatting options for generating text.
     You can set the field width and pad character by calling
@@ -990,7 +984,7 @@ QTextStream::QTextStream(QByteArray *array, QIODevice::OpenMode openMode)
     This constructor is convenient for working on constant
     strings. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 3
 */
 QTextStream::QTextStream(const QByteArray &array, QIODevice::OpenMode openMode)
     : d_ptr(new QTextStreamPrivate(this))
@@ -1020,7 +1014,7 @@ QTextStream::QTextStream(const QByteArray &array, QIODevice::OpenMode openMode)
     This constructor is useful for working directly with the common
     FILE based input and output streams: stdin, stdout and stderr. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 4
 */
 
 QTextStream::QTextStream(FILE *fileHandle, QIODevice::OpenMode openMode)
@@ -1318,11 +1312,11 @@ QTextStream::FieldAlignment QTextStream::fieldAlignment() const
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 5
 
     Output:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 6
 
     \sa padChar(), setFieldWidth()
 */
@@ -1455,11 +1449,18 @@ QTextStream::RealNumberNotation QTextStream::realNumberNotation() const
     describes the number of fraction digits QTextStream should
     write when generating real numbers.
 
+    The precision cannot be a negative value. The default value is 6.
+
     \sa realNumberPrecision(), setRealNumberNotation()
 */
 void QTextStream::setRealNumberPrecision(int precision)
 {
     Q_D(QTextStream);
+    if (precision < 0) {
+        qWarning("QTextStream::setRealNumberPrecision: Invalid precision (%d)", precision);
+        d->realNumberPrecision = 6;
+        return;
+    }
     d->realNumberPrecision = precision;
 }
 
@@ -1936,7 +1937,7 @@ bool QTextStreamPrivate::getReal(double *f)
     reference to the QTextStream, so several operators can be
     nested. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 7
 
     Whitespace is \e not skipped.
 */
@@ -2474,7 +2475,7 @@ QTextStream &QTextStream::operator<<(const QByteArray &array)
     string is assumed to be in ISO-8859-1 encoding. This operator
     is convenient when working with constant string data. Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 8
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 8
 
     Warning: QTextStream assumes that \a string points to a string of
     text, terminated by a '\0' character. If there is no terminating
@@ -2782,7 +2783,7 @@ QTextStream &center(QTextStream &stream)
 
     Equivalent to
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 9
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 9
 
     Note: On Windows, all '\n' characters are written as '\r\n' if
     QTextStream's device or string is opened using the QIODevice::Text flag.
@@ -2906,7 +2907,7 @@ void QTextStream::setCodec(QTextCodec *codec)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.io.qtextstream.cpp 10
+    \snippet doc/src/snippets/code/src_corelib_io_qtextstream.cpp 10
 
     \sa QTextCodec::codecForName()
 */
