@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -869,8 +863,8 @@ Qt::DropActions QTableModel::supportedDropActions() const
 /*!
     \class QTableWidgetSelectionRange
 
-    \brief The QTableWidgetSelectionRange class provides a container for
-    storing a selection range in a QTableWidget.
+    \brief The QTableWidgetSelectionRange class provides a way to interact with
+    selection in a model without using model indexes and a selection model.
 
     \ingroup model-view
 
@@ -878,6 +872,10 @@ Qt::DropActions QTableModel::supportedDropActions() const
     right rows and columns of a selection range in a table. The
     selections in the table may consist of several selection ranges.
 
+    \note If the item within the selection range is marked as not selectable,
+    e.g., \c{itemFlags() & Qt::ItemIsSelectable == 0} then it will not appear
+    in the selection range.
+
     \sa QTableWidget
 */
 
@@ -1157,7 +1155,9 @@ void QTableWidgetItem::setFlags(Qt::ItemFlags aflags)
 /*!
     \fn void QTableWidgetItem::setStatusTip(const QString &statusTip)
 
-    Sets the item's status tip to the string specified by \a statusTip.
+    Sets the status tip for the table item to the text specified by
+    \a statusTip. QTableWidget mouse tracking needs to be enabled for this
+    feature to work.
 
     \sa statusTip() setToolTip() setWhatsThis()
 */
@@ -1560,11 +1560,17 @@ QTableWidgetItem &QTableWidgetItem::operator=(const QTableWidgetItem &other)
 /*!
     \property QTableWidget::rowCount
     \brief the number of rows in the table
+
+    By default, for a table constructed without row and column counts,
+    this property contains a value of 0.
 */
 
 /*!
     \property QTableWidget::columnCount
     \brief the number of columns in the table
+
+    By default, for a table constructed without row and column counts,
+    this property contains a value of 0.
 */
 
 void QTableWidgetPrivate::setup()
@@ -1960,8 +1966,12 @@ void QTableWidget::setItem(int row, int column, QTableWidgetItem *item)
 {
     Q_D(QTableWidget);
     if (item) {
-        item->view = this;
-        d->model()->setItem(row, column, item);
+        if (item->view != 0) {
+            qWarning("QTableWidget: cannot insert an item that is already owned by another QTableWidget");
+        } else {
+            item->view = this;
+            d->model()->setItem(row, column, item);
+        }
     } else {
         delete takeItem(row, column);
     }
