@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -48,6 +42,8 @@
 #include "qpainter.h"
 #include "qpalette.h"
 
+QT_BEGIN_NAMESPACE
+
 /*!
     \fn void qDrawShadeLine(QPainter *painter, int x1, int y1, int x2, int y2,
                      const QPalette &palette, bool sunken,
@@ -76,10 +72,7 @@
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded line:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::HLine | QFrame::Sunken);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 0
 
     \sa qDrawShadeRect(), qDrawShadePanel(), QStyle
 */
@@ -192,10 +185,7 @@ void qDrawShadeLine(QPainter *p, int x1, int y1, int x2, int y2,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded rectangle:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::Box | QFrame::Raised);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 1
 
     \sa qDrawShadeLine(), qDrawShadePanel(), qDrawPlainRect(), QStyle
 */
@@ -296,10 +286,7 @@ void qDrawShadeRect(QPainter *p, int x, int y, int w, int h,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded panel:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle( QFrame::Panel | QFrame::Sunken);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 2
 
     \sa qDrawWinPanel(), qDrawShadeLine(), qDrawShadeRect(), QStyle
 */
@@ -470,10 +457,7 @@ void qDrawWinButton(QPainter *p, int x, int y, int w, int h,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded panel:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::WinPanel | QFrame::Raised);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 3
 
     \sa qDrawShadePanel(), qDrawWinButton(), QStyle
 */
@@ -509,10 +493,7 @@ void qDrawWinPanel(QPainter *p, int x, int y, int w, int h,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a plain rectangle:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::Box | QFrame::Plain);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 4
 
     \sa qDrawShadeRect(), QStyle
 */
@@ -571,10 +552,7 @@ void qDrawPlainRect(QPainter *p, int x, int y, int w, int h, const QColor &c,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded line:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::HLine | QFrame::Sunken);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 5
 
     \sa qDrawShadeRect(), qDrawShadePanel(), QStyle
 */
@@ -613,10 +591,7 @@ void qDrawShadeLine(QPainter *p, const QPoint &p1, const QPoint &p2,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded rectangle:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::Box | QFrame::Raised);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 6
 
     \sa qDrawShadeLine(), qDrawShadePanel(), qDrawPlainRect(), QStyle
 */
@@ -653,10 +628,7 @@ void qDrawShadeRect(QPainter *p, const QRect &r,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded panel:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle( QFrame::Panel | QFrame::Sunken);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 7
 
     \sa qDrawWinPanel(), qDrawShadeLine(), qDrawShadeRect(), QStyle
 */
@@ -717,10 +689,7 @@ void qDrawWinButton(QPainter *p, const QRect &r,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a shaded panel:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::WinPanel | QFrame::Raised);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 8
 
     \sa qDrawShadePanel(), qDrawWinButton(), QStyle
 */
@@ -747,10 +716,7 @@ void qDrawWinPanel(QPainter *p, const QRect &r,
     Alternatively you can use a QFrame widget and apply the
     QFrame::setFrameStyle() function to display a plain rectangle:
 
-    \code
-        QFrame frame:
-        frame.setFrameStyle(QFrame::Box | QFrame::Plain);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_painting_qdrawutil.cpp 9
 
     \sa qDrawShadeRect(), QStyle
 */
@@ -1065,5 +1031,7 @@ void qDrawItem(QPainter *p, Qt::GUIStyle gs,
         p->drawText(x, y, w, h, flags, text.left(len));
     }
 }
+
 #endif
 
+QT_END_NAMESPACE
