@@ -1,36 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -55,6 +56,8 @@
 #include "qaccessible.h"
 #endif
 
+QT_BEGIN_NAMESPACE
+
 class QDialPrivate : public QAbstractSliderPrivate
 {
     Q_DECLARE_PUBLIC(QDial)
@@ -64,7 +67,7 @@ public:
         wrapping = false;
         tracking = true;
         doNotEmit = false;
-        target = 3.7;
+        target = qreal(3.7);
     }
 
     qreal target;
@@ -201,6 +204,10 @@ int QDialPrivate::valueFromPoint(const QPoint &p) const
     \l pageStep, and the \key Home and \key End keys set the value to the
     defined \l minimum and \l maximum values.
 
+    If you are using the mouse wheel to adjust the dial, the increment value
+    is determined by the lesser value of \l{QApplication::wheelScrollLines()}
+    {wheelScrollLines} multipled by \l singleStep, and \l pageStep.
+
     \table
     \row \o \inlineimage plastique-dial.png Screenshot of a dial in the Plastique widget style
     \o \inlineimage windowsxp-dial.png Screenshot of a dial in the Windows XP widget style
@@ -388,6 +395,8 @@ bool QDial::wrapping() const
     possible it is a multiple of singleStep() that results in an
     on-screen notch size near notchTarget().
 
+    By default, this property has a value of 1.
+
     \sa notchTarget(), singleStep()
 */
 
@@ -505,5 +514,6 @@ bool QDial::event(QEvent *e)
     Use QAbstractSlider::sliderReleased() instead.
 */
 
+QT_END_NAMESPACE
 
 #endif // QT_NO_DIAL
