@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -65,7 +59,11 @@
 #include <qmacstyle_mac.h>
 #endif
 
-extern QString qt_setWindowTitle_helperHelper(const QString&, QWidget*); // qwidget.cpp
+QT_BEGIN_NAMESPACE
+
+extern QString qt_setWindowTitle_helperHelper(const QString&, const QWidget*); // qwidget.cpp
+
+extern QHash<QByteArray, QFont> *qt_app_fonts_hash(); // qapplication.cpp
 
 static inline bool hasFeature(const QDockWidget *dockwidget, QDockWidget::DockWidgetFeature feature)
 { return (dockwidget->features() & feature) == feature; }
@@ -97,9 +95,6 @@ static inline bool hasFeature(const QDockWidget *dockwidget, QDockWidget::DockWi
 
 */
 
-
-
-
 /******************************************************************************
 ** QDockWidgetTitleButton
 */
@@ -131,9 +126,9 @@ QSize QDockWidgetTitleButton::sizeHint() const
 {
     ensurePolished();
 
-    int size = 2*style()->pixelMetric(QStyle::PM_DockWidgetTitleBarButtonMargin);
+    int size = 2*style()->pixelMetric(QStyle::PM_DockWidgetTitleBarButtonMargin, 0, this);
     if (!icon().isNull()) {
-        int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize);
+        int iconSize = style()->pixelMetric(QStyle::PM_SmallIconSize, 0, this);
         const QPixmap pm = icon().pixmap(iconSize);
         size += qMax(pm.width(), pm.height());
     }
@@ -158,7 +153,7 @@ void QDockWidgetTitleButton::paintEvent(QPaintEvent *)
     QPainter p(this);
 
     QRect r = rect();
-    QStyleOption opt;
+    QStyleOptionToolButton opt;
     opt.init(this);
     opt.state |= QStyle::State_AutoRaise;
 
@@ -175,17 +170,14 @@ void QDockWidgetTitleButton::paintEvent(QPaintEvent *)
         style()->drawPrimitive(QStyle::PE_PanelButtonTool, &opt, &p, this);
     }
 
-    int shiftHorizontal = opt.state & QStyle::State_Sunken ? style()->pixelMetric(QStyle::PM_ButtonShiftHorizontal, &opt, this) : 0;
-    int shiftVertical = opt.state & QStyle::State_Sunken ? style()->pixelMetric(QStyle::PM_ButtonShiftVertical, &opt, this) : 0;
-
-    r.adjust(2, 2, -2, -2);
-    r.translate(shiftHorizontal, shiftVertical);
-
-    QPixmap pm = icon().pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize), isEnabled() ?
-                                underMouse() ? QIcon::Active : QIcon::Normal
-                                    : QIcon::Disabled,
-                                isDown() ? QIcon::On : QIcon::Off);
-    style()->drawItemPixmap(&p, r, Qt::AlignCenter, pm);
+    opt.icon = icon();
+    opt.subControls = 0;
+    opt.activeSubControls = 0;
+    opt.features = QStyleOptionToolButton::None;
+    opt.arrowType = Qt::NoArrow;
+    int size = style()->pixelMetric(QStyle::PM_SmallIconSize, 0, this);
+    opt.iconSize = QSize(size, size);
+    style()->drawComplexControl(QStyle::CC_ToolButton, &opt, &p, this);
 }
 
 /******************************************************************************
@@ -204,7 +196,7 @@ QDockWidgetLayout::~QDockWidgetLayout()
 
 bool QDockWidgetLayout::nativeWindowDeco() const
 {
-#if defined(Q_WS_X11) || defined(Q_WS_QWS)
+#if defined(Q_WS_X11) || defined(Q_WS_QWS) || defined(Q_OS_WINCE)
     return false;
 #else
     return parentWidget()->isWindow() && item_list[QDockWidgetLayout::TitleBar] == 0;
@@ -271,12 +263,12 @@ QSize QDockWidgetLayout::sizeFromContent(const QSize &content, bool floating) co
     QDockWidget *w = qobject_cast<QDockWidget*>(parentWidget());
     bool customTitleBar = item_list[TitleBar] != 0;
     bool nativeDeco = floating && !customTitleBar;
-#if defined(Q_WS_X11) || defined(Q_WS_QWS)
+#if defined(Q_WS_X11) || defined(Q_WS_QWS) || defined(Q_OS_WINCE)
     nativeDeco = false;
 #endif
 
     int fw = floating && !nativeDeco
-            ? w->style()->pixelMetric(QStyle::PM_DockWidgetFrameWidth, 0, 0)
+            ? w->style()->pixelMetric(QStyle::PM_DockWidgetFrameWidth, 0, w)
             : 0;
 
     const int th = titleHeight();
@@ -296,6 +288,7 @@ QSize QDockWidgetLayout::sizeFromContent(const QSize &content, bool floating) co
         result.setHeight(-1);
 
     QSize min = w->minimumSize();
+    QSize max = w->maximumSize();
 
     /* A floating dockwidget will automatically get its minimumSize set to the layout's
        minimum size + deco. We're *not* interested in this, we only take minimumSize()
@@ -304,14 +297,23 @@ QSize QDockWidgetLayout::sizeFromContent(const QSize &content, bool floating) co
        minimum size + window decorations. */
 
     uint explicitMin = 0;
-    if (w->d_func()->extra != 0)
+    uint explicitMax = 0;
+    if (w->d_func()->extra != 0) {
         explicitMin = w->d_func()->extra->explicitMinSize;
+        explicitMax = w->d_func()->extra->explicitMaxSize;
+    }
 
     if (!(explicitMin & Qt::Horizontal) || min.width() == 0)
         min.setWidth(-1);
     if (!(explicitMin & Qt::Vertical) || min.height() == 0)
         min.setHeight(-1);
-    return result.boundedTo(w->maximumSize()).expandedTo(min);
+
+    if (!(explicitMax & Qt::Horizontal))
+        max.setWidth(QWIDGETSIZE_MAX);
+    if (!(explicitMax & Qt::Vertical))
+        max.setHeight(QWIDGETSIZE_MAX);
+
+    return result.boundedTo(max).expandedTo(min);
 }
 
 QSize QDockWidgetLayout::sizeHint() const
@@ -325,6 +327,17 @@ QSize QDockWidgetLayout::sizeHint() const
     return sizeFromContent(content, w->isFloating());
 }
 
+QSize QDockWidgetLayout::maximumSize() const
+{
+    if (item_list[Content] != 0) {
+        const QSize content = item_list[Content]->maximumSize();
+        return sizeFromContent(content, parentWidget()->isWindow());
+    } else {
+        return parentWidget()->maximumSize();
+    }
+
+}
+
 QSize QDockWidgetLayout::minimumSize() const
 {
     QDockWidget *w = qobject_cast<QDockWidget*>(parentWidget());
@@ -336,20 +349,20 @@ QSize QDockWidgetLayout::minimumSize() const
     return sizeFromContent(content, w->isFloating());
 }
 
-QWidget *QDockWidgetLayout::widget(Role r) const
+QWidget *QDockWidgetLayout::widgetForRole(Role r) const
 {
     QLayoutItem *item = item_list.at(r);
     return item == 0 ? 0 : item->widget();
 }
 
-QLayoutItem *QDockWidgetLayout::item(Role r) const
+QLayoutItem *QDockWidgetLayout::itemForRole(Role r) const
 {
     return item_list.at(r);
 }
 
-void QDockWidgetLayout::setWidget(Role r, QWidget *w)
+void QDockWidgetLayout::setWidgetForRole(Role r, QWidget *w)
 {
-    QWidget *old = widget(r);
+    QWidget *old = widgetForRole(r);
     if (old != 0) {
         old->hide();
         removeWidget(old);
@@ -357,7 +370,7 @@ void QDockWidgetLayout::setWidget(Role r, QWidget *w)
 
     if (w != 0) {
         addChildWidget(w);
-        item_list[r] = new QWidgetItem(w);
+        item_list[r] = new QWidgetItemV2(w);
         w->show();
     } else {
         item_list[r] = 0;
@@ -380,7 +393,7 @@ int QDockWidgetLayout::minimumTitleWidth() const
 {
     QDockWidget *q = qobject_cast<QDockWidget*>(parentWidget());
 
-    if (QWidget *title = widget(TitleBar))
+    if (QWidget *title = widgetForRole(TitleBar))
         return pick(verticalTitleBar, title->minimumSizeHint());
 
     QSize closeSize(0, 0);
@@ -404,7 +417,7 @@ int QDockWidgetLayout::titleHeight() const
 {
     QDockWidget *q = qobject_cast<QDockWidget*>(parentWidget());
 
-    if (QWidget *title = widget(TitleBar))
+    if (QWidget *title = widgetForRole(TitleBar))
         return perp(verticalTitleBar, title->sizeHint());
 
     QSize closeSize(0, 0);
@@ -420,7 +433,6 @@ int QDockWidgetLayout::titleHeight() const
     QFontMetrics titleFontMetrics = q->fontMetrics();
 #ifdef Q_WS_MAC
     if (qobject_cast<QMacStyle *>(q->style())) {
-        extern QHash<QByteArray, QFont> *qt_app_fonts_hash(); // qapplication.cpp
         QFont font = qt_app_fonts_hash()->value("QToolButton", q->font());
         titleFontMetrics = QFontMetrics(font);
     }
@@ -438,7 +450,7 @@ void QDockWidgetLayout::setGeometry(const QRect &geometry)
     bool nativeDeco = nativeWindowDeco();
 
     int fw = q->isFloating() && !nativeDeco
-            ? q->style()->pixelMetric(QStyle::PM_DockWidgetFrameWidth, 0, 0)
+            ? q->style()->pixelMetric(QStyle::PM_DockWidgetFrameWidth, 0, q)
             : 0;
 
     if (nativeDeco) {
@@ -494,14 +506,6 @@ void QDockWidgetLayout::setGeometry(const QRect &geometry)
             item->setGeometry(r);
         }
     }
-
-    QLayoutItem *item = item_list[Content];
-    if (item != 0 && q->isFloating()) {
-        QSize s = sizeFromContent(item->maximumSize(), true);
-        q->setMaximumSize(s);
-    } else {
-        q->setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
-    }
 }
 
 void QDockWidgetLayout::setVerticalTitleBar(bool b)
@@ -532,16 +536,21 @@ QSize QDockWidgetItem::minimumSize() const
 
 QSize QDockWidgetItem::maximumSize() const
 {
-    if (QLayoutItem *item = dockWidgetChildItem())
+    if (QLayoutItem *item = dockWidgetChildItem()) {
         return dockWidgetLayout()->sizeFromContent(item->maximumSize(), false);
-    return QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
+    } else {
+        return QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
+    }
 }
 
+
 QSize QDockWidgetItem::sizeHint() const
 {
-    if (QLayoutItem *item = dockWidgetChildItem())
+    if (QLayoutItem *item = dockWidgetChildItem()) {
         return dockWidgetLayout()->sizeFromContent(item->sizeHint(), false);
-    return minimumSize();
+    } else {
+        return QWidgetItem::sizeHint();
+    }
 }
 
 /******************************************************************************
@@ -553,14 +562,17 @@ void QDockWidgetPrivate::init()
     Q_Q(QDockWidget);
 
     QDockWidgetLayout *layout = new QDockWidgetLayout(q);
+    layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
 
     QAbstractButton *button = new QDockWidgetTitleButton(q);
+    button->setObjectName(QLatin1String("qt_dockwidget_floatbutton"));
     QObject::connect(button, SIGNAL(clicked()), q, SLOT(_q_toggleTopLevel()));
-    layout->setWidget(QDockWidgetLayout::FloatButton, button);
+    layout->setWidgetForRole(QDockWidgetLayout::FloatButton, button);
 
     button = new QDockWidgetTitleButton(q);
+    button->setObjectName(QLatin1String("qt_dockwidget_closebutton"));
     QObject::connect(button, SIGNAL(clicked()), q, SLOT(close()));
-    layout->setWidget(QDockWidgetLayout::CloseButton, button);
+    layout->setWidgetForRole(QDockWidgetLayout::CloseButton, button);
 
     resizer = new QWidgetResizeHandler(q);
     resizer->setMovingEnabled(false);
@@ -626,7 +638,7 @@ void QDockWidgetPrivate::updateButtons()
     QStyleOptionDockWidget opt;
     q->initStyleOption(&opt);
 
-    bool customTitleBar = layout->widget(QDockWidgetLayout::TitleBar) != 0;
+    bool customTitleBar = layout->widgetForRole(QDockWidgetLayout::TitleBar) != 0;
     bool nativeDeco = layout->nativeWindowDeco();
     bool hideButtons = nativeDeco || customTitleBar;
 
@@ -634,13 +646,13 @@ void QDockWidgetPrivate::updateButtons()
     bool canFloat = hasFeature(q, QDockWidget::DockWidgetFloatable);
 
     QAbstractButton *button
-        = qobject_cast<QAbstractButton*>(layout->widget(QDockWidgetLayout::FloatButton));
-    button->setIcon(q->style()->standardIcon(QStyle::SP_TitleBarNormalButton));
+        = qobject_cast<QAbstractButton*>(layout->widgetForRole(QDockWidgetLayout::FloatButton));
+    button->setIcon(q->style()->standardIcon(QStyle::SP_TitleBarNormalButton, &opt, q));
     button->setVisible(canFloat && !hideButtons);
 
     button
-        = qobject_cast <QAbstractButton*>(layout->widget(QDockWidgetLayout::CloseButton));
-    button->setIcon(q->style()->standardIcon(QStyle::SP_TitleBarCloseButton));
+        = qobject_cast <QAbstractButton*>(layout->widgetForRole(QDockWidgetLayout::CloseButton));
+    button->setIcon(q->style()->standardIcon(QStyle::SP_TitleBarCloseButton, &opt, q));
     button->setVisible(canClose && !hideButtons);
 
     q->setAttribute(Qt::WA_ContentsPropagated,
@@ -666,6 +678,8 @@ void QDockWidgetPrivate::initDrag(const QPoint &pos, bool nca)
     Q_ASSERT(win != 0);
     QMainWindowLayout *layout = qobject_cast<QMainWindowLayout*>(win->layout());
     Q_ASSERT(layout != 0);
+    if (layout->layoutState.indexOf(q).isEmpty()) //The dock widget has not been added into the main window
+        return;
     if (layout->pluggingWidget != 0) // the main window is animating a docking operation
         return;
 
@@ -718,7 +732,7 @@ void QDockWidgetPrivate::endDrag(bool abort)
         Q_ASSERT(layout != 0);
 
         if (abort || !layout->plug(state->widgetItem)) {
-            if (::hasFeature(q, QDockWidget::DockWidgetFloatable)) {
+            if (hasFeature(q, QDockWidget::DockWidgetFloatable)) {
                 if (state->ownWidgetItem)
                     delete state->widgetItem;
                 layout->restore();
@@ -733,7 +747,7 @@ void QDockWidgetPrivate::endDrag(bool abort)
                 QDockWidgetLayout *myLayout
                     = qobject_cast<QDockWidgetLayout*>(q->layout());
                 resizer->setActive(QWidgetResizeHandler::Resize,
-                                    myLayout->widget(QDockWidgetLayout::TitleBar) != 0);
+                                    myLayout->widgetForRole(QDockWidgetLayout::TitleBar) != 0);
 #endif
                 undockedGeometry = q->geometry();
                 q->activateWindow();
@@ -778,7 +792,7 @@ void QDockWidgetPrivate::mousePressEvent(QMouseEvent *event)
         if (!titleArea.contains(event->pos()))
             return;
         // check if the tool window is movable... do nothing if it is not
-        if (!::hasFeature(q, QDockWidget::DockWidgetMovable))
+        if (!hasFeature(q, QDockWidget::DockWidgetMovable))
             return;
 
         if (qobject_cast<QMainWindow*>(q->parentWidget()) == 0)
@@ -814,7 +828,7 @@ void QDockWidgetPrivate::mouseDoubleClickEvent(QMouseEvent *event)
             return;
         if (!titleArea.contains(event->pos()))
             return;
-        if (!::hasFeature(q, QDockWidget::DockWidgetFloatable))
+        if (!hasFeature(q, QDockWidget::DockWidgetFloatable))
             return;
         _q_toggleTopLevel();
     }
@@ -999,8 +1013,8 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
     Qt::WindowFlags flags = floating ? Qt::Tool : Qt::Widget;
 
     QDockWidgetLayout *layout = qobject_cast<QDockWidgetLayout*>(q->layout());
-    bool nativeDeco = floating && layout->widget(QDockWidgetLayout::TitleBar) == 0;
-#if defined(Q_WS_X11) || defined(Q_WS_QWS)
+    bool nativeDeco = floating && layout->widgetForRole(QDockWidgetLayout::TitleBar) == 0;
+#if defined(Q_WS_X11) || defined(Q_WS_QWS) || defined(Q_OS_WINCE)
     nativeDeco = false;
 #endif
 
@@ -1031,8 +1045,14 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
     if (!hidden)
         q->show();
 
-    if (floating != wasFloating)
+    if (floating != wasFloating) {
         emit q->topLevelChanged(floating);
+        if (!floating) {
+            QMainWindowLayout *mwlayout = qobject_cast<QMainWindowLayout *>(q->parentWidget()->layout());
+            if (mwlayout)
+                emit q->dockLocationChanged(mwlayout->dockWidgetArea(q));
+        }
+    }
 
     resizer->setActive(QWidgetResizeHandler::Resize, !unplug && floating && !nativeDeco);
 }
@@ -1055,7 +1075,7 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
     \image mainwindow-docks.png
 
     Dock windows can be moved inside their current area, moved into
-    new areas and floated (e.g. undocked) by the end-user.  The
+    new areas and floated (e.g., undocked) by the end-user.  The
     QDockWidget API allows the programmer to restrict the dock widgets
     ability to move, float and close, as well as the areas in which
     they can be placed.
@@ -1076,7 +1096,7 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
     implemented in the child widget. QDockWidget will respect them, adjusting
     its own constraints to include the frame and title. Size constraints
     should not be set on the QDockWidget itself, because they change depending
-    on wether it is docked; a docked QDockWidget has no frame and a smaller title
+    on whether it is docked; a docked QDockWidget has no frame and a smaller title
     bar.
 
     \sa QMainWindow, {Dock Widgets Example}
@@ -1110,6 +1130,8 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
 /*!
     \property QDockWidget::windowTitle
     \internal
+
+    By default, this property contains an empty string.
 */
 
 /*!
@@ -1158,24 +1180,33 @@ QDockWidget::~QDockWidget()
 QWidget *QDockWidget::widget() const
 {
     QDockWidgetLayout *layout = qobject_cast<QDockWidgetLayout*>(this->layout());
-    return layout->widget(QDockWidgetLayout::Content);
+    return layout->widgetForRole(QDockWidgetLayout::Content);
 }
 
 /*!
     Sets the widget for the dock widget to \a widget.
 
+    If the dock widget is visible when \a widget is added, you must
+    \l{QWidget::}{show()} it explicitly. 
+
+    Note that you must add the layout of the \a widget before you call
+    this function; if not, the \a widget will not be visible.
+
     \sa widget()
 */
 void QDockWidget::setWidget(QWidget *widget)
 {
     QDockWidgetLayout *layout = qobject_cast<QDockWidgetLayout*>(this->layout());
-    layout->setWidget(QDockWidgetLayout::Content, widget);
+    layout->setWidgetForRole(QDockWidgetLayout::Content, widget);
 }
 
 /*!
     \property QDockWidget::features
     \brief whether the dock widget is movable, closable, and floatable
 
+    By default, this property is set to a combination of DockWidgetClosable,
+    DockWidgetMovable and DockWidgetFloatable.
+
     \sa DockWidgetFeature
 */
 
@@ -1209,6 +1240,8 @@ QDockWidget::DockWidgetFeatures QDockWidget::features() const
     window "on top" of its parent QMainWindow, instead of being
     docked in the QMainWindow.
 
+    By default, this property is true.
+
     \sa isWindow()
 */
 void QDockWidget::setFloating(bool floating)
@@ -1221,15 +1254,14 @@ void QDockWidget::setFloating(bool floating)
 
     QRect r = d->undockedGeometry;
 
+    d->setWindowState(floating, false, floating ? r : QRect());
     if (floating && r.isNull()) {
         QDockWidgetLayout *layout = qobject_cast<QDockWidgetLayout*>(this->layout());
         QRect titleArea = layout->titleArea();
         int h = layout->verticalTitleBar ? titleArea.width() : titleArea.height();
         QPoint p = mapToGlobal(QPoint(h, h));
-        r = QRect(p, size());
+        move(p);
     }
-
-    d->setWindowState(floating, false, floating ? r : QRect());
 }
 
 /*!
@@ -1308,7 +1340,7 @@ void QDockWidget::paintEvent(QPaintEvent *event)
 
     QDockWidgetLayout *layout
         = qobject_cast<QDockWidgetLayout*>(this->layout());
-    bool customTitleBar = layout->widget(QDockWidgetLayout::TitleBar) != 0;
+    bool customTitleBar = layout->widgetForRole(QDockWidgetLayout::TitleBar) != 0;
     bool nativeDeco = layout->nativeWindowDeco();
 
     if (!nativeDeco && !customTitleBar) {
@@ -1503,14 +1535,7 @@ QAction * QDockWidget::toggleViewAction() const
     \i When DockWidgetVerticalTitleBar is set on QDockWidget, the title
        bar widget is repositioned accordingly. In resizeEvent(), the title
        bar should check what orientation it should assume:
-       \code
-       QDockWidget *dockWidget = qobject_cast<QDockWidget*>(parentWidget());
-       if (dockWidget->features() & QDockWidget::DockWidgetVerticalTitleBar) {
-           // I need to be vertical
-       } else {
-           // I need to be horizontal
-       }
-       \endcode
+       \snippet doc/src/snippets/code/src_gui_widgets_qdockwidget.cpp 0
 
     \i The title bar widget must have a valid QWidget::sizeHint() and
        QWidget::minimumSizeHint(). These functions should take into account
@@ -1529,8 +1554,12 @@ void QDockWidget::setTitleBarWidget(QWidget *widget)
     Q_D(QDockWidget);
     QDockWidgetLayout *layout
         = qobject_cast<QDockWidgetLayout*>(this->layout());
-    layout->setWidget(QDockWidgetLayout::TitleBar, widget);
+    layout->setWidgetForRole(QDockWidgetLayout::TitleBar, widget);
     d->updateButtons();
+    if (isWindow()) {
+        //this ensures the native decoration is drawn
+        d->setWindowState(true /*floating*/, true /*unplug*/);
+    }
 }
 
 /*!
@@ -1545,9 +1574,12 @@ QWidget *QDockWidget::titleBarWidget() const
 {
     QDockWidgetLayout *layout
         = qobject_cast<QDockWidgetLayout*>(this->layout());
-    return layout->widget(QDockWidgetLayout::TitleBar);
+    return layout->widgetForRole(QDockWidgetLayout::TitleBar);
 }
 
+QT_END_NAMESPACE
+
 #include "qdockwidget.moc"
 #include "moc_qdockwidget.cpp"
+
 #endif // QT_NO_DOCKWIDGET
