@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -64,30 +58,10 @@
 #include "qaccessible.h"
 #endif
 
-#include "private/qabstractbutton_p.h"
+#include "private/qpushbutton_p.h"
 
+QT_BEGIN_NAMESPACE
 
-class QPushButtonPrivate : public QAbstractButtonPrivate
-{
-    Q_DECLARE_PUBLIC(QPushButton)
-public:
-    enum AutoDefaultValue { Off = 0, On = 1, Auto = 2 };
-
-    QPushButtonPrivate()
-        : QAbstractButtonPrivate(QSizePolicy::PushButton), autoDefault(Auto),
-          defaultButton(false), flat(false), menuOpen(false) {}
-
-    inline void init() { resetLayoutItemMargins(); }
-    void resetLayoutItemMargins();
-    void _q_popupPressed();
-    QDialog *dialogParent() const;
-
-    QPointer<QMenu> menu;
-    uint autoDefault : 2;
-    uint defaultButton : 1;
-    uint flat : 1;
-    uint menuOpen : 1;
-};
 
 /*!
     \class QPushButton qpushbutton.h
@@ -107,9 +81,7 @@ public:
     preceding the preferred character with an ampersand in the
     text. For example:
 
-    \code
-        QPushButton *button = new QPushButton("&Download", this);
-    \endcode
+    \snippet doc/src/snippets/code/src_gui_widgets_qpushbutton.cpp 0
 
     In this example the shortcut is \e{Alt+D}. See the \l
     {QShortcut#mnemonic}{QShortcut} documentation for details (to
@@ -298,6 +270,14 @@ QPushButton::QPushButton(const QIcon& icon, const QString &text, QWidget *parent
     d->init();
 }
 
+/*! \internal
+ */
+QPushButton::QPushButton(QPushButtonPrivate &dd, QWidget *parent)
+    : QAbstractButton(dd, parent)
+{
+    Q_D(QPushButton);
+    d->init();
+}
 
 /*!
     Destroys the push button.
@@ -737,5 +717,6 @@ QPushButton::QPushButton(const QIcon& icon, const QString &text, QWidget *parent
     Use menu() instead.
 */
 
+QT_END_NAMESPACE
 
 #include "moc_qpushbutton.cpp"
