@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -60,6 +54,8 @@
 #include <qtextobject.h>
 #include <qdesktopservices.h>
 
+QT_BEGIN_NAMESPACE
+
 class QTextBrowserPrivate : public QTextEditPrivate
 {
     Q_DECLARE_PUBLIC(QTextBrowser)
@@ -79,11 +75,27 @@ public:
             : hpos(0), vpos(0), focusIndicatorPosition(-1),
               focusIndicatorAnchor(-1) {}
         QUrl url;
+        QString title;
         int hpos;
         int vpos;
         int focusIndicatorPosition, focusIndicatorAnchor;
     };
 
+    HistoryEntry history(int i) const
+    {
+        if (i <= 0)
+            if (-i < stack.count())
+                return stack[stack.count()+i-1];
+            else
+                return HistoryEntry();
+        else
+            if (i <= forwardStack.count())
+                return forwardStack[forwardStack.count()-i];
+            else
+                return HistoryEntry();
+    }
+
+
     HistoryEntry createHistoryEntry() const;
     void restoreHistoryEntry(const HistoryEntry entry);
 
@@ -120,7 +132,10 @@ public:
 
     void setSource(const QUrl &url);
 
-    QUrl resolveUrl(const QUrl &url) const;
+    // re-imlemented from QTextEditPrivate
+    virtual QUrl resolveUrl(const QUrl &url) const;
+    inline QUrl resolveUrl(const QString &url) const
+    { return resolveUrl(QUrl::fromEncoded(url.toUtf8())); }
 
 #ifdef QT_KEYPAD_NAVIGATION
     void keypadMove(bool next);
@@ -129,18 +144,6 @@ public:
 #endif
 };
 
-static bool isAbsoluteFileName(const QString &name)
-{
-    return !name.isEmpty()
-           && (name[0] == QLatin1Char('/')
-#if defined(Q_WS_WIN)
-               || (name[0].isLetter() && name[1] == QLatin1Char(':')) || name.startsWith(QLatin1String("\\\\"))
-#endif
-               || (name[0]  == QLatin1Char(':') && name[1] == QLatin1Char('/'))
-              );
-
-}
-
 QString QTextBrowserPrivate::findFile(const QUrl &name) const
 {
     QString fileName;
@@ -149,7 +152,7 @@ QString QTextBrowserPrivate::findFile(const QUrl &name) const
     else
         fileName = name.toLocalFile();
 
-    if (isAbsoluteFileName(fileName))
+    if (QFileInfo(fileName).isAbsolute())
         return fileName;
 
     foreach (QString path, searchPaths) {
@@ -172,7 +175,7 @@ QUrl QTextBrowserPrivate::resolveUrl(const QUrl &url) const
     // correctly to "foo.html#someanchor"
     if (!(currentURL.isRelative()
           || (currentURL.scheme() == QLatin1String("file")
-              && !isAbsoluteFileName(currentURL.toLocalFile())))
+              && !QFileInfo(currentURL.toLocalFile()).isAbsolute()))
           || (url.hasFragment() && url.path().isEmpty())) {
         return currentURL.resolved(url);
     }
@@ -303,7 +306,13 @@ void QTextBrowserPrivate::setSource(const QUrl &url)
         home = url;
 
     if (doSetText) {
+#ifndef QT_NO_TEXTHTMLPARSER
         q->QTextEdit::setHtml(txt);
+        q->document()->setMetaInformation(QTextDocument::DocumentUrl, currentURL.toString());
+#else
+        q->QTextEdit::setPlainText(txt);
+#endif
+
 #ifdef QT_KEYPAD_NAVIGATION
         prevFocus.movePosition(QTextCursor::Start);
 #endif
@@ -317,9 +326,11 @@ void QTextBrowserPrivate::setSource(const QUrl &url)
         hbar->setValue(0);
         vbar->setValue(0);
     }
-#ifdef QT_KEYPAD_NAVIGATION 
-    lastKeypadScrollValue = vbar->value(); 
-#endif 
+#ifdef QT_KEYPAD_NAVIGATION
+    lastKeypadScrollValue = vbar->value();
+    emit q->highlighted(QUrl());
+    emit q->highlighted(QString());
+#endif
 
 #ifndef QT_NO_CURSOR
     if (q->isVisible())
@@ -519,6 +530,7 @@ QTextBrowserPrivate::HistoryEntry QTextBrowserPrivate::createHistoryEntry() cons
 {
     HistoryEntry entry;
     entry.url = q_func()->source();
+    entry.title = q_func()->documentTitle();
     entry.hpos = hbar->value();
     entry.vpos = vbar->value();
 
@@ -541,13 +553,19 @@ void QTextBrowserPrivate::restoreHistoryEntry(const HistoryEntry entry)
         QTextCursor cursor(control->document());
         cursor.setPosition(entry.focusIndicatorAnchor);
         cursor.setPosition(entry.focusIndicatorPosition, QTextCursor::KeepAnchor);
-        control->setCursorIsFocusIndicator(true);
         control->setTextCursor(cursor);
+        control->setCursorIsFocusIndicator(true);
     }
-#ifdef QT_KEYPAD_NAVIGATION 
-    lastKeypadScrollValue = vbar->value(); 
-    prevFocus = control->textCursor(); 
-#endif 
+#ifdef QT_KEYPAD_NAVIGATION
+    lastKeypadScrollValue = vbar->value();
+    prevFocus = control->textCursor();
+
+    Q_Q(QTextBrowser);
+    const QString href = prevFocus.charFormat().anchorHref();
+    QUrl url = resolveUrl(href);
+    emit q->highlighted(url);
+    emit q->highlighted(url.toString());
+#endif
 }
 
 /*!
@@ -606,11 +624,15 @@ void QTextBrowserPrivate::restoreHistoryEntry(const HistoryEntry entry)
 /*!
     \property QTextBrowser::readOnly
     \brief whether the text browser is read-only
+
+    By default, this property is true.
 */
 
 /*!
     \property QTextBrowser::undoRedoEnabled
     \brief whether the text browser supports undo/redo operations
+
+    By default, this property is false.
 */
 
 void QTextBrowserPrivate::init()
@@ -678,6 +700,8 @@ QTextBrowser::~QTextBrowser()
     the browser window itself. Otherwise, the document is displayed
     normally in the text browser with the text set to the contents of
     the named document with setHtml().
+
+    By default, this property contains an empty URL.
 */
 QUrl QTextBrowser::source() const
 {
@@ -694,6 +718,8 @@ QUrl QTextBrowser::source() const
     content
 
     QTextBrowser uses this list to locate images and documents.
+
+    By default, this property contains an empty string list.
 */
 
 QStringList QTextBrowser::searchPaths() const
@@ -739,6 +765,7 @@ void QTextBrowser::setSource(const QUrl &url)
 
     QTextBrowserPrivate::HistoryEntry entry;
     entry.url = url;
+    entry.title = documentTitle();
     entry.hpos = 0;
     entry.vpos = 0;
     d->stack.push(entry);
@@ -752,6 +779,8 @@ void QTextBrowser::setSource(const QUrl &url)
         d->forwardStack.clear();
         emit forwardAvailable(false);
     }
+
+    emit historyChanged();
 }
 
 /*!
@@ -770,6 +799,15 @@ void QTextBrowser::setSource(const QUrl &url)
     when the user navigates or goes forward().
 */
 
+/*!
+    \fn void QTextBrowser::historyChanged()
+    \since 4.4
+
+    This signal is emitted when the history changes.
+
+    \sa historyTitle(), historyUrl()
+*/
+
 /*!
     \fn void QTextBrowser::sourceChanged(const QUrl &src)
 
@@ -828,6 +866,7 @@ void QTextBrowser::backward()
     d->restoreHistoryEntry(d->stack.top()); // previous entry
     emit backwardAvailable(d->stack.count() > 1);
     emit forwardAvailable(true);
+    emit historyChanged();
 }
 
 /*!
@@ -850,11 +889,12 @@ void QTextBrowser::forward()
     d->restoreHistoryEntry(d->stack.top());
     emit backwardAvailable(true);
     emit forwardAvailable(!d->forwardStack.isEmpty());
+    emit historyChanged();
 }
 
 /*!
-    Changes the document displayed to be the first document the
-    browser displayed.
+    Changes the document displayed to be the first document from
+    the history.
 */
 void QTextBrowser::home()
 {
@@ -1015,9 +1055,10 @@ void QTextBrowser::paintEvent(QPaintEvent *e)
 }
 
 /*!
-    This function is called when the document is loaded. The \a type
-    indicates the type of resource to be loaded. For each image in
-    the document, this function is called once.
+    This function is called when the document is loaded and for
+    each image in the document. The \a type indicates the type of resource
+    to be loaded. An invalid QVariant is returned if the resource cannot be
+    loaded.
 
     The default implementation ignores \a type and tries to locate
     the resources by interpreting \a name as a file name. If it is
@@ -1048,7 +1089,6 @@ QVariant QTextBrowser::loadResource(int /*type*/, const QUrl &name)
         data = f.readAll();
         f.close();
     } else {
-        qWarning("QTextBrowser: Cannot open '%s' for reading", name.toString().toLocal8Bit().data());
         return QVariant();
     }
 
@@ -1095,10 +1135,76 @@ void QTextBrowser::clearHistory()
 {
     Q_D(QTextBrowser);
     d->forwardStack.clear();
-    if (!d->stack.isEmpty())
-        d->stack.resize(1);
+    if (!d->stack.isEmpty()) {
+        QTextBrowserPrivate::HistoryEntry historyEntry = d->stack.top();
+        d->stack.resize(0);
+        d->stack.push(historyEntry);
+        d->home = historyEntry.url;
+    }
     emit forwardAvailable(false);
     emit backwardAvailable(false);
+    emit historyChanged();
+}
+
+/*!
+   Returns the url of the HistoryItem.
+
+    \table
+    \header \i Input            \i Return
+    \row \i \a{i} < 0  \i \l backward() history
+    \row \i\a{i} == 0 \i current, see QTextBrowser::source()
+    \row \i \a{i} > 0  \i \l forward() history
+    \endtable
+
+    \since 4.4
+*/
+QUrl QTextBrowser::historyUrl(int i) const
+{
+    Q_D(const QTextBrowser);
+    return d->history(i).url;
+}
+
+/*!
+    Returns the documentTitle() of the HistoryItem.
+
+    \table
+    \header \i Input            \i Return
+    \row \i \a{i} < 0  \i \l backward() history
+    \row \i \a{i} == 0 \i current, see QTextBrowser::source()
+    \row \i \a{i} > 0  \i \l forward() history
+    \endtable
+
+    \snippet doc/src/snippets/code/src_gui_widgets_qtextbrowser.cpp 0
+
+    \since 4.4
+*/
+QString QTextBrowser::historyTitle(int i) const
+{
+    Q_D(const QTextBrowser);
+    return d->history(i).title;
+}
+
+
+/*!
+    Returns the number of locations forward in the history.
+
+    \since 4.4
+*/
+int QTextBrowser::forwardHistoryCount() const
+{
+    Q_D(const QTextBrowser);
+    return d->forwardStack.count();
+}
+
+/*!
+    Returns the number of locations backward in the history.
+
+    \since 4.4
+*/
+int QTextBrowser::backwardHistoryCount() const
+{
+    Q_D(const QTextBrowser);
+    return d->stack.count()-1;
 }
 
 /*!
@@ -1154,5 +1260,8 @@ bool QTextBrowser::event(QEvent *e)
     return QTextEdit::event(e);
 }
 
+QT_END_NAMESPACE
+
 #include "moc_qtextbrowser.cpp"
+
 #endif // QT_NO_TEXTBROWSER
