@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -407,10 +401,10 @@ void QTextEditPrivate::_q_ensureVisible(const QRectF &_rect)
     navigation, and text may only be selected with the mouse:
     \table
     \header \i Keypresses \i Action
-    \row \i Qt::UpArrow        \i Moves one line up.
-    \row \i Qt::DownArrow        \i Moves one line down.
-    \row \i Qt::LeftArrow        \i Moves one character to the left.
-    \row \i Qt::RightArrow        \i Moves one character to the right.
+    \row \i Up        \i Moves one line up.
+    \row \i Down        \i Moves one line down.
+    \row \i Left        \i Moves one character to the left.
+    \row \i Right        \i Moves one character to the right.
     \row \i PageUp        \i Moves one (viewport) page up.
     \row \i PageDown        \i Moves one (viewport) page down.
     \row \i Home        \i Moves to the beginning of the text.
@@ -492,12 +486,12 @@ void QTextEditPrivate::_q_ensureVisible(const QRectF &_rect)
     \row \i Shift+Delete \i Deletes the selected text and copies it to the clipboard.
     \row \i Ctrl+Z \i Undoes the last operation.
     \row \i Ctrl+Y \i Redoes the last operation.
-    \row \i LeftArrow \i Moves the cursor one character to the left.
-    \row \i Ctrl+LeftArrow \i Moves the cursor one word to the left.
-    \row \i RightArrow \i Moves the cursor one character to the right.
-    \row \i Ctrl+RightArrow \i Moves the cursor one word to the right.
-    \row \i UpArrow \i Moves the cursor one line up.
-    \row \i DownArrow \i Moves the cursor one line down.
+    \row \i Left \i Moves the cursor one character to the left.
+    \row \i Ctrl+Left \i Moves the cursor one word to the left.
+    \row \i Right \i Moves the cursor one character to the right.
+    \row \i Ctrl+Right \i Moves the cursor one word to the right.
+    \row \i Up \i Moves the cursor one line up.
+    \row \i Down \i Moves the cursor one line down.
     \row \i PageUp \i Moves the cursor one page up.
     \row \i PageDown \i Moves the cursor one page down.
     \row \i Home \i Moves the cursor to the beginning of the line.
@@ -508,9 +502,8 @@ void QTextEditPrivate::_q_ensureVisible(const QRectF &_rect)
     \endtable
 
     To select (mark) text hold down the Shift key whilst pressing one
-    of the movement keystrokes, for example, \e{Shift+Right Arrow}
-    will select the character to the right, and \e{Shift+Ctrl+Right
-    Arrow} will select the word to the right, etc.
+    of the movement keystrokes, for example, \e{Shift+Right}
+    will select the character to the right, and \e{Shift+Ctrl+Right} will select the word to the right, etc.
 
     \sa QTextDocument, QTextCursor, {Application Example},
 	{Syntax Highlighter Example}, {Rich Text Processing}
@@ -520,13 +513,17 @@ void QTextEditPrivate::_q_ensureVisible(const QRectF &_rect)
     \property QTextEdit::plainText
     \since 4.3
 
-    This property gets and sets the text edit's contents as plain
+    This property gets and sets the text editor's contents as plain
     text. Previous contents are removed and undo/redo history is reset
-    when the property is set. If the text edit has another content
-    type, it will not be replaced by plain text when you call
-    toPlainText().
+    when the property is set.
 
-		\sa html
+    If the text edit has another content type, it will not be replaced
+    by plain text if you call toPlainText().
+
+    By default, for an editor with no contents, this property contains
+    an empty string.
+
+    \sa html
 */
 
 /*!
@@ -1032,6 +1029,7 @@ void QTextEdit::selectAll()
 bool QTextEdit::event(QEvent *e)
 {
     Q_D(QTextEdit);
+#ifndef QT_NO_CONTEXTMENU
     if (e->type() == QEvent::ContextMenu
         && static_cast<QContextMenuEvent *>(e)->reason() == QContextMenuEvent::Keyboard) {
         Q_D(QTextEdit);
@@ -1046,8 +1044,9 @@ bool QTextEdit::event(QEvent *e)
                || e->type() == QEvent::ToolTip) {
         d->sendControlEvent(e);
     }
+#endif // QT_NO_CONTEXTMENU
 #ifdef QT_KEYPAD_NAVIGATION
-    else if (e->type() == QEvent::EnterEditFocus || e->type() == QEvent::LeaveEditFocus) {
+    if (e->type() == QEvent::EnterEditFocus || e->type() == QEvent::LeaveEditFocus) {
         if (QApplication::keypadNavigationEnabled())
             d->sendControlEvent(e);
     }
@@ -1143,6 +1142,9 @@ void QTextEdit::setPlainText(const QString &text)
     text is correctly decoded when a QString containing HTML is created
     and passed to setHtml().
 
+    By default, for a newly-created, empty document, this property contains
+    text to describe an HTML 4.0 document with no body text.
+
     \sa {Supported HTML Subset}, plainText
 */
 
@@ -1555,6 +1557,7 @@ bool QTextEdit::focusNextPrevChild(bool next)
     return QAbstractScrollArea::focusNextPrevChild(next);
 }
 
+#ifndef QT_NO_CONTEXTMENU
 /*!
   \fn void QTextEdit::contextMenuEvent(QContextMenuEvent *event)
 
@@ -1568,13 +1571,14 @@ bool QTextEdit::focusNextPrevChild(bool next)
 
   Information about the event is passed in the \a event object.
 
-  \snippet doc/src/snippets/code/src.gui.widgets.qtextedit.cpp 0
+  \snippet doc/src/snippets/code/src_gui_widgets_qtextedit.cpp 0
 */
 void QTextEdit::contextMenuEvent(QContextMenuEvent *e)
 {
     Q_D(QTextEdit);
     d->sendControlEvent(e);
 }
+#endif // QT_NO_CONTEXTMENU
 
 #ifndef QT_NO_DRAGANDDROP
 /*! \reimp
@@ -1821,6 +1825,16 @@ QString QTextEdit::anchorAt(const QPoint& pos) const
 /*!
    \property QTextEdit::overwriteMode
    \since 4.1
+   \brief whether text entered by the user will overwrite existing text
+
+   As with many text editors, the text editor widget can be configured
+   to insert or overwrite existing text with new text entered by the user.
+
+   If this property is true, existing text is overwritten, character-for-character
+   by new text; otherwise, text is inserted at the cursor position, displacing
+   existing text.
+
+   By default, this property is false (new text does not overwrite existing text).
 */
 
 bool QTextEdit::overwriteMode() const
@@ -1839,6 +1853,8 @@ void QTextEdit::setOverwriteMode(bool overwrite)
     \property QTextEdit::tabStopWidth
     \brief the tab stop width in pixels
     \since 4.1
+
+    By default, this property contains a value of 80.
 */
 
 int QTextEdit::tabStopWidth() const
@@ -2108,7 +2124,7 @@ void QTextEdit::setAutoFormatting(AutoFormatting features)
 
     It is equivalent to
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qtextedit.cpp 1
+    \snippet doc/src/snippets/code/src_gui_widgets_qtextedit.cpp 1
  */
 void QTextEdit::insertPlainText(const QString &text)
 {
@@ -2122,7 +2138,7 @@ void QTextEdit::insertPlainText(const QString &text)
 
     It is equivalent to:
 
-    \snippet doc/src/snippets/code/src.gui.widgets.qtextedit.cpp 2
+    \snippet doc/src/snippets/code/src_gui_widgets_qtextedit.cpp 2
 
     \note When using this function with a style sheet, the style sheet will
     only apply to the current block in the document. In order to apply a style
@@ -2261,6 +2277,9 @@ void QTextEdit::setTabChangesFocus(bool b)
 /*!
     \property QTextEdit::documentTitle
     \brief the title of the document parsed from the text.
+
+    By default, for a newly-created, empty document, this property contains
+    an empty string.
 */
 
 /*!
@@ -2303,6 +2322,8 @@ void QTextEdit::setLineWrapMode(LineWrapMode wrap)
     column number (in character columns) from the left edge of the
     text edit at which text should be wrapped.
 
+    By default, this property contains a value of 0.
+
     \sa lineWrapMode
 */
 
@@ -2323,6 +2344,8 @@ void QTextEdit::setLineWrapColumnOrWidth(int w)
     \property QTextEdit::wordWrapMode
     \brief the mode QTextEdit will use when wrapping text by words
 
+    By default, this property is set to QTextOption::WrapAtWordBoundaryOrAnywhere.
+
     \sa QTextOption::WrapMode
 */
 
