@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -1418,7 +1412,7 @@ static int qt_timeout_value(int msecs, int elapsed)
     The following example waits up to one second for a connection
     to be established:
 
-    \snippet doc/src/snippets/code/src.network.socket.qabstractsocket.cpp 0
+    \snippet doc/src/snippets/code/src_network_socket_qabstractsocket.cpp 0
 
     If msecs is -1, this function will not time out.
 
@@ -1512,7 +1506,7 @@ bool QAbstractSocket::waitForConnected(int msecs)
     This function blocks until data is available for reading and the
     \l{QIODevice::}{readyRead()} signal has been emitted. The function
     will timeout after \a msecs milliseconds; the default timeout is
-    3000 milliseconds.
+    30000 milliseconds.
 
     The function returns true if the readyRead() signal is emitted and
     there is data available for reading; otherwise it returns false
@@ -1654,7 +1648,7 @@ bool QAbstractSocket::waitForBytesWritten(int msecs)
     The following example waits up to one second for a connection
     to be closed:
 
-    \snippet doc/src/snippets/code/src.network.socket.qabstractsocket.cpp 1
+    \snippet doc/src/snippets/code/src_network_socket_qabstractsocket.cpp 1
 
     If msecs is -1, this function will not time out.
 
@@ -1762,7 +1756,7 @@ bool QAbstractSocket::isSequential() const
      This function is most commonly used when reading data from the
      socket in a loop. For example:
 
-     \snippet doc/src/snippets/code/src.network.socket.qabstractsocket.cpp 2
+     \snippet doc/src/snippets/code/src_network_socket_qabstractsocket.cpp 2
 
      \sa bytesAvailable(), readyRead()
  */
@@ -2265,7 +2259,7 @@ void QAbstractSocket::setSocketError(SocketError socketError)
     To disable the use of a proxy for this socket, use the
     QNetworkProxy::NoProxy proxy type:
 
-    \snippet doc/src/snippets/code/src.network.socket.qabstractsocket.cpp 3
+    \snippet doc/src/snippets/code/src_network_socket_qabstractsocket.cpp 3
 
 
     \sa proxy(), QNetworkProxy
@@ -2356,13 +2350,13 @@ QNetworkProxy QAbstractSocket::proxy() const
 /*!
     \fn void QAbstractSocket::connectionClosed()
 
-    Use closed() instead.
+    Use disconnected() instead.
 */
 
 /*!
     \fn void QAbstractSocket::delayedCloseFinished()
 
-    Use closed() instead.
+    Use disconnected() instead.
 */
 #endif // QT3_SUPPORT
 
