@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -57,6 +51,8 @@
 #include "qtimer.h"
 #include <limits.h>
 
+QT_BEGIN_NAMESPACE
+
 // If the operation is expected to take this long (as predicted by
 // progress time), show the progress dialog.
 static const int defaultShowTime    = 4000;
@@ -143,19 +139,7 @@ public:
   running to ensure that the application doesn't freeze. Do the
   operation in a loop, call \l setProgress() at intervals, and check
   for cancellation with wasCanceled(). For example:
-\code
-Q3ProgressDialog progress("Copying files...", "Abort Copy", numFiles,
-                          this, "progress", true);
-for (int i = 0; i < numFiles; i++) {
-    progress.setProgress(i);
-    qApp->processEvents();
-
-    if (progress.wasCanceled())
-        break;
-    //... copy one file
-}
-progress.setProgress(numFiles);
-\endcode
+\snippet doc/src/snippets/code/src_qt3support_dialogs_q3progressdialog.cpp 0
 
   A modeless progress dialog is suitable for operations that take
   place in the background, where the user is able to interact with the
@@ -167,32 +151,7 @@ progress.setProgress(numFiles);
   You need to have an event loop to be running, connect the
   canceled() signal to a slot that stops the operation, and call \l
   setProgress() at intervals. For example:
-\code
-Operation::Operation(QObject *parent = 0)
-    : QObject(parent), steps(0)
-{
-    pd = new Q3ProgressDialog("Operation in progress.", "Cancel", 100);
-    connect(pd, SIGNAL(canceled()), this, SLOT(cancel()));
-    t = new QTimer(this);
-    connect(t, SIGNAL(timeout()), this, SLOT(perform()));
-    t->start(0);
-}
-
-void Operation::perform()
-{
-    pd->setProgress(steps);
-    //... perform one percent of the operation
-    steps++;
-    if (steps > pd->totalSteps())
-        t->stop();
-}
-
-void Operation::cancel()
-{
-    t->stop();
-    //... cleanup
-}
-\endcode
+\snippet doc/src/snippets/code/src_qt3support_dialogs_q3progressdialog.cpp 1
 
 
   In both modes the progress dialog may be customized by
@@ -630,8 +589,8 @@ int Q3ProgressDialog::progress() const
 
 void Q3ProgressDialog::setProgress(int progress)
 {
-    if (progress == bar()->progress() ||
-         bar()->progress() == -1 && progress == bar()->totalSteps())
+    if (progress == bar()->progress()
+        || (bar()->progress() == -1 && progress == bar()->totalSteps()))
         return;
 
     bar()->setProgress(progress);
@@ -882,4 +841,6 @@ void Q3ProgressDialog::forceShow()
 }
 
 
+QT_END_NAMESPACE
+
 #endif
