@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtScript module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -63,6 +57,12 @@
 
 #include <QtCore/qobjectdefs.h>
 
+#if defined Q_CC_MSVC && !defined Q_CC_MSVC_NET
+#include <QtCore/qnumeric.h>
+#endif
+
+QT_BEGIN_NAMESPACE
+
 namespace QScript {
     namespace AST {
     class Node;
@@ -80,6 +80,7 @@ public:
 
     static inline QScriptContextPrivate *get(QScriptContext *q);
     static inline const QScriptContextPrivate *get(const QScriptContext *q);
+    static QScriptContext *get(QScriptContextPrivate *d);
 
     static inline QScriptContext *create();
 
@@ -93,6 +94,10 @@ public:
 
     inline void throwException();
     inline bool hasUncaughtException() const;
+    const QScriptInstruction *findExceptionHandler(const QScriptInstruction *ip) const;
+    const QScriptInstruction *findExceptionHandlerRecursive(
+        const QScriptInstruction *ip, QScriptContextPrivate **handlerContext) const;
+    QScriptContextPrivate *exceptionHandlerContext() const;
     inline void recover();
     QStringList backtrace() const;
 
@@ -114,6 +119,10 @@ public:
                 return false;
 
             case QScript::NumberType:
+#if defined Q_CC_MSVC && !defined Q_CC_MSVC_NET
+                if (qIsNaN(lhs.m_number_value) || qIsNaN(rhs.m_number_value))
+                    return false;
+#endif
                 return lhs.m_number_value < rhs.m_number_value;
 
             case QScript::IntegerType:
@@ -170,6 +179,9 @@ public:
     QScriptValueImpl throwError(QScriptContext::Error error, const QString &text);
     QScriptValueImpl throwError(const QString &text);
 
+#ifndef Q_SCRIPT_NO_EVENT_NOTIFY
+    qint64 scriptId() const;
+#endif
     QString fileName() const;
     QString functionName() const;
     void setDebugInformation(QScriptValueImpl *error) const;
@@ -230,8 +242,12 @@ public:
     bool catching;
     bool m_calledAsConstructor;
 
+    int calleeMetaIndex;
+
     QScriptContext *q_ptr;
 };
 
+QT_END_NAMESPACE
+
 #endif // QT_NO_SCRIPT
 #endif
