@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtScript module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -58,12 +52,16 @@
 #include <QtCore/QSet>
 #include <QtCore/QStringList>
 #include <QtCore/QTime>
+#include <QtCore/QVector>
 
 #include "qscriptengine.h"
 #include "qscriptrepository_p.h"
 #include "qscriptgc_p.h"
 #include "qscriptobjectfwd_p.h"
 #include "qscriptclassinfo_p.h"
+#include "qscriptstring_p.h"
+
+QT_BEGIN_NAMESPACE
 
 //
 //  W A R N I N G
@@ -76,6 +74,7 @@
 // We mean it.
 //
 
+class QScriptClass;
 class QScriptContext;
 
 namespace QScript {
@@ -130,13 +129,13 @@ public:
     QScriptNameIdImpl *id_length;
     QScriptNameIdImpl *id_callee;
     QScriptNameIdImpl *id___proto__;
-    QScriptNameIdImpl *id___fileName__;
     QScriptNameIdImpl *id___qt_sender__;
 };
 
 } // namespace QScript
 
 #ifndef QT_NO_QOBJECT
+class QScriptQObjectData;
 class QScriptMetaObject;
 #endif
 
@@ -165,20 +164,25 @@ class QScriptEnginePrivate
 
 public:
     inline QScriptEnginePrivate();
-    ~QScriptEnginePrivate();
+    virtual ~QScriptEnginePrivate();
 
     void init();
 
     static inline QScriptEnginePrivate *get(QScriptEngine *q);
 
-    QScript::AST::Node *createAbstractSyntaxTree(const QString &source, int &lineNumber);
+    QScript::AST::Node *createAbstractSyntaxTree(
+        const QString &source, int lineNumber,
+        QString *errorMessage, int *errorLineNumber);
     QScript::AST::Node *changeAbstractSyntaxTree(QScript::AST::Node *program);
 
     inline QScript::AST::Node *abstractSyntaxTree() const;
-    inline QString errorMessage() const;
     inline bool hasUncaughtException() const;
     inline QScriptValueImpl uncaughtException() const;
     QStringList uncaughtExceptionBacktrace() const;
+    void clearExceptions();
+#ifndef QT_NO_QOBJECT
+    void emitSignalHandlerException();
+#endif
 
     inline QScriptContext *currentContext() const;
     inline QScriptContext *pushContext();
@@ -195,6 +199,8 @@ public:
     inline bool blockGC(bool block);
 
     void gc();
+    bool isCollecting() const;
+    void processMarkStack(int generation);
 
     inline void adjustBytesAllocated(int bytes);
 
@@ -207,18 +213,22 @@ public:
     inline QScriptValueImpl newArray(const QScript::Array &value);
     inline QScriptValueImpl newArray(uint length = 0);
 
-    void evaluate(QScriptContextPrivate *context, const QString &contents, int lineNumber, const QString &fileName = QString());
+    void evaluate(QScriptContextPrivate *context, const QString &contents,
+                  int lineNumber, const QString &fileName = QString());
 
     inline void setLexer(QScript::Lexer *lexer);
 
     inline void setNodePool(QScript::MemoryPool *pool);
 
-    inline QScriptClassInfo *registerClass(const QString &pname, QScript::Type type);
+    inline QScriptClassInfo *registerClass(const QString &pname, int type);
 
     inline QScriptClassInfo *registerClass(const QString &name);
 
+    int registerCustomClassType();
+
     inline QScriptValueImpl createFunction(QScriptInternalFunctionSignature fun,
-                                           int length, QScriptClassInfo *classInfo);
+                                           int length, QScriptClassInfo *classInfo,
+                                           const QString &name = QString());
 
     inline QString toString(QScriptNameIdImpl *id) const;
     inline QString memberName(const QScript::Member &member) const;
@@ -281,17 +291,19 @@ public:
 
     inline void newObject(QScriptValueImpl *o, const QScriptValueImpl &proto,
                           QScriptClassInfo *oc = 0);
-
     inline void newObject(QScriptValueImpl *o, QScriptClassInfo *oc = 0);
+    QScriptValueImpl newObject(QScriptClass *scriptClass, const QScriptValueImpl &data);
 
     inline QScriptValueImpl newObject();
 
-    inline QScriptValueImpl newVariant(const QVariant &value);
+    inline void newVariant(QScriptValueImpl *out, const QVariant &value,
+                           bool setDefaultPrototype = true);
 
 #ifndef QT_NO_QOBJECT
-    inline QScriptValueImpl newQObject(QObject *object,
-                                       QScriptEngine::ValueOwnership ownership = QScriptEngine::QtOwnership,
-                                       const QScriptEngine::QObjectWrapOptions &options = 0);
+    void newQObject(QScriptValueImpl *out, QObject *object,
+                    QScriptEngine::ValueOwnership ownership = QScriptEngine::QtOwnership,
+                    const QScriptEngine::QObjectWrapOptions &options = 0,
+                    bool setDefaultPrototype = true);
 
 # ifndef Q_SCRIPT_NO_QMETAOBJECT_CACHE
     inline QScriptMetaObject *cachedMetaObject(const QMetaObject *meta);
@@ -302,6 +314,10 @@ public:
 
     inline QScriptNameIdImpl *intern(const QChar *u, int s);
 
+    QScriptString internedString(const QString &str);
+    QScriptString internedString(QScriptNameIdImpl *nid);
+    void uninternString(QScriptStringPrivate *d);
+
     inline QScriptValueImpl valueFromVariant(const QVariant &v);
 
     inline QScriptValueImpl undefinedValue();
@@ -338,18 +354,92 @@ public:
     inline bool strictlyEquals(const QScriptValueImpl &lhs, const QScriptValueImpl &rhs) const;
 
     QScriptValuePrivate *registerValue(const QScriptValueImpl &value);
-
     inline void unregisterValue(QScriptValuePrivate *p);
 
     inline QScriptValueImpl globalObject() const;
 
+    QScriptValueImpl objectById(qint64 id) const;
+
     QScriptValueImpl importExtension(const QString &extension);
+    QStringList availableExtensions() const;
+    QStringList importedExtensions() const;
 
     inline void maybeProcessEvents();
     void setupProcessEvents();
     void processEvents();
 
+#ifndef QT_NO_QOBJECT
+    QScriptQObjectData *qobjectData(QObject *object);
+
+    bool scriptConnect(QObject *sender, const char *signal,
+                       const QScriptValueImpl &receiver,
+                       const QScriptValueImpl &function);
+    bool scriptDisconnect(QObject *sender, const char *signal,
+                          const QScriptValueImpl &receiver,
+                          const QScriptValueImpl &function);
+
+    bool scriptConnect(QObject *sender, int index,
+                       const QScriptValueImpl &receiver,
+                       const QScriptValueImpl &function,
+                       const QScriptValueImpl &senderWrapper = QScriptValueImpl());
+    bool scriptDisconnect(QObject *sender, int index,
+                          const QScriptValueImpl &receiver,
+                          const QScriptValueImpl &function);
+
+    bool scriptConnect(const QScriptValueImpl &signal,
+                       const QScriptValueImpl &receiver,
+                       const QScriptValueImpl &function);
+    bool scriptDisconnect(const QScriptValueImpl &signal,
+                          const QScriptValueImpl &receiver,
+                          const QScriptValueImpl &function);
+
+    void _q_objectDestroyed(QObject *object);
+
+    void disposeQObject(QObject *object);
+    void deletePendingQObjects();
+
+    static bool convertToNativeQObject(const QScriptValueImpl &value,
+                                       const QByteArray &targetType,
+                                       void **result);
+#endif
+
+    void abortEvaluation(const QScriptValueImpl &result);
+    inline bool shouldAbort() const;
+    inline void resetAbortFlag();
+
+    void setAgent(QScriptEngineAgent *agent);
+    QScriptEngineAgent *agent() const;
+
+    void agentDeleted(QScriptEngineAgent *agent);
+
+#ifndef Q_SCRIPT_NO_EVENT_NOTIFY
+    qint64 nextScriptId();
+    inline bool shouldNotify() const;
+    inline void notifyScriptLoad(qint64 id, const QString &program,
+                                 const QString &fileName, int lineNumber);
+    void notifyScriptLoad_helper(qint64 id, const QString &program,
+                                 const QString &fileName, int lineNumber);
+    inline void notifyScriptUnload(qint64 id);
+    void notifyScriptUnload_helper(qint64 id);
+    inline void notifyPositionChange(QScriptContextPrivate *ctx);
+    void notifyPositionChange_helper(QScriptContextPrivate *ctx);
+    inline void notifyContextPush();
+    void notifyContextPush_helper();
+    inline void notifyContextPop();
+    void notifyContextPop_helper();
+    inline void notifyFunctionEntry(QScriptContextPrivate *ctx);
+    void notifyFunctionEntry_helper(QScriptContextPrivate *ctx);
+    inline void notifyFunctionExit(QScriptContextPrivate *ctx);
+    void notifyFunctionExit_helper(QScriptContextPrivate *ctx);
+    inline void notifyException(QScriptContextPrivate *ctx);
+    void notifyException_helper(QScriptContextPrivate *ctx);
+    inline void notifyExceptionCatch(QScriptContextPrivate *ctx);
+    void notifyExceptionCatch_helper(QScriptContextPrivate *ctx);
+#endif // Q_SCRIPT_NO_EVENT_NOTIFY
+
 public: // attributes
+    bool m_evaluating;
+    bool m_abort;
     int m_callDepth;
     int m_maxCallDepth;
     int m_gc_depth;
@@ -361,15 +451,16 @@ public: // attributes
     QVector<QScriptNameIdImpl*> m_tempStringRepository;
     QScriptNameIdImpl **m_string_hash_base;
     int m_string_hash_size;
-    QScript::GCAlloc<QScriptObject> objectAllocator;
+    QScript::GCAlloc<QScriptObject, QScriptEngine*> objectAllocator;
     QScript::Repository<QScriptContext, QScriptContextPrivate> m_frameRepository;
     QScriptContext *m_context;
     QScriptValueImpl *tempStackBegin;
     QScriptValueImpl *tempStackEnd;
-    QString m_errorMessage;
     QScript::AST::Node *m_abstractSyntaxTree;
     QScript::Lexer *m_lexer;
     QScript::MemoryPool *m_pool;
+    QStringList m_exceptionBacktrace;
+    qint64 m_scriptCounter;
 
     QScript::Ecma::Object *objectConstructor;
     QScript::Ecma::Number *numberConstructor;
@@ -389,31 +480,35 @@ public: // attributes
 
     QScriptFunction *m_evalFunction;
 
+    QScriptTypeInfo *m_type_boolean;
+    QScriptTypeInfo *m_type_number;
+    QScriptTypeInfo *m_type_int;
+    QScriptTypeInfo *m_type_null;
+    QScriptTypeInfo *m_type_object;
+    QScriptTypeInfo *m_type_pointer;
+    QScriptTypeInfo *m_type_reference;
+    QScriptTypeInfo *m_type_string;
+    QScriptTypeInfo *m_type_undefined;
+
     QList<QScriptClassInfo*> m_allocated_classes;
-    QScriptClassInfo *m_class_activation;
-    QScriptClassInfo *m_class_boolean;
-    QScriptClassInfo *m_class_double;
-    QScriptClassInfo *m_class_function;
-    QScriptClassInfo *m_class_int;
-    QScriptClassInfo *m_class_null;
     QScriptClassInfo *m_class_object;
-    QScriptClassInfo *m_class_pointer;
-    QScriptClassInfo *m_class_reference;
-    QScriptClassInfo *m_class_string;
-    QScriptClassInfo *m_class_undefined;
-    QScriptClassInfo *m_class_variant;
-    QScriptClassInfo *m_class_qobject;
-    QScriptClassInfo *m_class_qmetaobject;
+    QScriptClassInfo *m_class_function;
     QScriptClassInfo *m_class_with;
     QScriptClassInfo *m_class_arguments;
+    QScriptClassInfo *m_class_activation;
 
-    QHash<QScript::Type, QScriptClassInfo*> m_classes;
     int m_class_prev_id;
+    qint64 m_next_object_id;
 
     QScript::Repository<QScriptValuePrivate, QScriptValuePrivate> m_handleRepository;
     QHash<QScriptObject*, QScriptValuePrivate*> m_objectHandles;
     QHash<QScriptNameIdImpl*, QScriptValuePrivate*> m_stringHandles;
     QVector<QScriptValuePrivate*> m_otherHandles;
+
+    QScript::Repository<QScriptStringPrivate,
+                        QScriptStringPrivate> m_internedStringRepository;
+    QHash<QScriptNameIdImpl*, QScriptStringPrivate*> m_internedStrings;
+
 #ifndef QT_NO_REGEXP
     QHash<QString, QRegExp> m_regExpLiterals;
 #endif
@@ -428,7 +523,13 @@ public: // attributes
     int m_processEventIncr;
     QTime m_processEventTracker;
 
+    QList<QScriptEngineAgent*> m_agents;
+    QScriptEngineAgent *m_agent;
+
 #ifndef QT_NO_QOBJECT
+    QList<QObject*> m_qobjectsToBeDeleted;
+    QHash<QObject*, QScriptQObjectData*> m_qobjectData;
+
 # ifndef Q_SCRIPT_NO_QMETAOBJECT_CACHE
     QHash<const QMetaObject*, QScriptMetaObject*> m_cachedMetaObjects;
 # endif
@@ -439,5 +540,8 @@ public: // attributes
 #endif
 };
 
+QT_END_NAMESPACE
+
 #endif // QT_NO_SCRIPT
+
 #endif
