@@ -1,18 +1,24 @@
-QT_CLASS_LIB(QScriptable, QtScript, qscriptable.h)
-QT_CLASS_LIB(QScriptContext, QtScript, qscriptcontext.h)
-QT_CLASS_LIB(QScriptEngine, QtScript, qscriptengine.h)
-QT_CLASS_LIB(QScriptExtensionInterface, QtScript, qscriptextensioninterface.h)
-QT_CLASS_LIB(QScriptExtensionPlugin, QtScript, qscriptextensionplugin.h)
-QT_CLASS_LIB(QScriptValueList, QtScript, qscriptvalue.h)
-QT_CLASS_LIB(QScriptValue, QtScript, qscriptvalue.h)
-QT_CLASS_LIB(QScriptValueIterator, QtScript, qscriptvalueiterator.h)
-QT_CLASS_LIB(QBasicAtomic, QtCore, qatomic_parisc.h)
-QT_CLASS_LIB(QBasicAtomicPointer, QtCore, qatomic_parisc.h)
 QT_CLASS_LIB(QTextCodec, QtCore, qtextcodec.h)
 QT_CLASS_LIB(QTextEncoder, QtCore, qtextcodec.h)
 QT_CLASS_LIB(QTextDecoder, QtCore, qtextcodec.h)
 QT_CLASS_LIB(QTextCodecFactoryInterface, QtCore, qtextcodecplugin.h)
 QT_CLASS_LIB(QTextCodecPlugin, QtCore, qtextcodecplugin.h)
+QT_CLASS_LIB(QFuture, QtCore, qfuture.h)
+QT_CLASS_LIB(QFutureIterator, QtCore, qfuture.h)
+QT_CLASS_LIB(QMutableFutureIterator, QtCore, qfuture.h)
+QT_CLASS_LIB(QFuture, QtCore, qfuture.h)
+QT_CLASS_LIB(QFutureInterfaceBase, QtCore, qfutureinterface.h)
+QT_CLASS_LIB(QFutureInterface, QtCore, qfutureinterface.h)
+QT_CLASS_LIB(QFutureInterface, QtCore, qfutureinterface.h)
+QT_CLASS_LIB(QFutureSynchronizer, QtCore, qfuturesynchronizer.h)
+QT_CLASS_LIB(QFutureWatcherBase, QtCore, qfuturewatcher.h)
+QT_CLASS_LIB(QFutureWatcher, QtCore, qfuturewatcher.h)
+QT_CLASS_LIB(QFutureWatcher, QtCore, qfuturewatcher.h)
+QT_CLASS_LIB(QRunnable, QtCore, qrunnable.h)
+QT_CLASS_LIB(QtConcurrentFilter, QtCore, qtconcurrentfilter.h)
+QT_CLASS_LIB(QtConcurrentMap, QtCore, qtconcurrentmap.h)
+QT_CLASS_LIB(QtConcurrentRun, QtCore, qtconcurrentrun.h)
+QT_CLASS_LIB(QThreadPool, QtCore, qthreadpool.h)
 QT_CLASS_LIB(QtEndian, QtCore, qendian.h)
 QT_CLASS_LIB(QtGlobal, QtCore, qglobal.h)
 QT_CLASS_LIB(QUintForSize, QtCore, qglobal.h)
@@ -120,8 +126,10 @@ QT_CLASS_LIB(QArgument, QtCore, qobjectdefs.h)
 QT_CLASS_LIB(QReturnArgument, QtCore, qobjectdefs.h)
 QT_CLASS_LIB(QMetaObject, QtCore, qobjectdefs.h)
 QT_CLASS_LIB(QPointer, QtCore, qpointer.h)
+QT_CLASS_LIB(QSharedMemory, QtCore, qsharedmemory.h)
 QT_CLASS_LIB(QSignalMapper, QtCore, qsignalmapper.h)
 QT_CLASS_LIB(QSocketNotifier, QtCore, qsocketnotifier.h)
+QT_CLASS_LIB(QSystemSemaphore, QtCore, qsystemsemaphore.h)
 QT_CLASS_LIB(QTimer, QtCore, qtimer.h)
 QT_CLASS_LIB(QTranslator, QtCore, qtranslator.h)
 QT_CLASS_LIB(QVariant, QtCore, qvariant.h)
@@ -134,10 +142,10 @@ QT_CLASS_LIB(QtPlugin, QtCore, qplugin.h)
 QT_CLASS_LIB(QtPluginInstanceFunction, QtCore, qplugin.h)
 QT_CLASS_LIB(QPluginLoader, QtCore, qpluginloader.h)
 QT_CLASS_LIB(QUuid, QtCore, quuid.h)
-QT_CLASS_LIB(QBasicAtomic, QtCore, qatomic.h)
-QT_CLASS_LIB(QBasicAtomicPointer, QtCore, qatomic.h)
-QT_CLASS_LIB(QAtomic, QtCore, qatomic.h)
+QT_CLASS_LIB(QAtomicInt, QtCore, qatomic.h)
 QT_CLASS_LIB(QAtomicPointer, QtCore, qatomic.h)
+QT_CLASS_LIB(QBasicAtomicInt, QtCore, qbasicatomic.h)
+QT_CLASS_LIB(QBasicAtomicPointer, QtCore, qbasicatomic.h)
 QT_CLASS_LIB(QMutex, QtCore, qmutex.h)
 QT_CLASS_LIB(QMutexLocker, QtCore, qmutex.h)
 QT_CLASS_LIB(QMutex, QtCore, qmutex.h)
@@ -194,8 +202,8 @@ QT_CLASS_LIB(QListIterator, QtCore, qlist.h)
 QT_CLASS_LIB(QMutableListIterator, QtCore, qlist.h)
 QT_CLASS_LIB(QListIterator, QtCore, qlist.h)
 QT_CLASS_LIB(QMutableListIterator, QtCore, qlist.h)
-QT_CLASS_LIB(QLocale, QtCore, qlocale.h)
 QT_CLASS_LIB(QSystemLocale, QtCore, qlocale.h)
+QT_CLASS_LIB(QLocale, QtCore, qlocale.h)
 QT_CLASS_LIB(QMapData, QtCore, qmap.h)
 QT_CLASS_LIB(QMap, QtCore, qmap.h)
 QT_CLASS_LIB(QMultiMap, QtCore, qmap.h)
@@ -230,6 +238,7 @@ QT_CLASS_LIB(QStringListIterator, QtCore, qstringlist.h)
 QT_CLASS_LIB(QMutableStringListIterator, QtCore, qstringlist.h)
 QT_CLASS_LIB(QStringList, QtCore, qstringlist.h)
 QT_CLASS_LIB(QStringMatcher, QtCore, qstringmatcher.h)
+QT_CLASS_LIB(QTextBoundaryFinder, QtCore, qtextboundaryfinder.h)
 QT_CLASS_LIB(QTimeLine, QtCore, qtimeline.h)
 QT_CLASS_LIB(QVarLengthArray, QtCore, qvarlengtharray.h)
 QT_CLASS_LIB(QVectorData, QtCore, qvector.h)
@@ -239,6 +248,18 @@ QT_CLASS_LIB(QVectorIterator, QtCore, qvector.h)
 QT_CLASS_LIB(QMutableVectorIterator, QtCore, qvector.h)
 QT_CLASS_LIB(QVectorIterator, QtCore, qvector.h)
 QT_CLASS_LIB(QMutableVectorIterator, QtCore, qvector.h)
+QT_CLASS_LIB(QXmlStreamStringRef, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamAttribute, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamAttributes, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamNamespaceDeclaration, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamNamespaceDeclarations, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamNotationDeclaration, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamNotationDeclarations, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamEntityDeclaration, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamEntityDeclarations, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamEntityResolver, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamReader, QtCore, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamWriter, QtCore, qxmlstream.h)
 QT_CLASS_LIB(QMacGLCompatTypes, QtOpenGL, qgl.h)
 QT_CLASS_LIB(QMacGLCompatTypes, QtOpenGL, qgl.h)
 QT_CLASS_LIB(QMacCompatGLint, QtOpenGL, qgl.h)
@@ -281,41 +302,131 @@ QT_CLASS_LIB(QXmlEntityResolver, QtXml, qxml.h)
 QT_CLASS_LIB(QXmlLexicalHandler, QtXml, qxml.h)
 QT_CLASS_LIB(QXmlDeclHandler, QtXml, qxml.h)
 QT_CLASS_LIB(QXmlDefaultHandler, QtXml, qxml.h)
-QT_CLASS_LIB(QXmlStreamStringRef, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamAttribute, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamAttributes, QtXml, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamEntityDeclaration, QtXml, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamEntityDeclarations, QtXml, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamEntityResolver, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamNamespaceDeclaration, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamNamespaceDeclarations, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamNotationDeclaration, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamNotationDeclarations, QtXml, qxmlstream.h)
-QT_CLASS_LIB(QXmlStreamEntityDeclaration, QtXml, qxmlstream.h)
-QT_CLASS_LIB(QXmlStreamEntityDeclarations, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamReader, QtXml, qxmlstream.h)
+QT_CLASS_LIB(QXmlStreamStringRef, QtXml, qxmlstream.h)
 QT_CLASS_LIB(QXmlStreamWriter, QtXml, qxmlstream.h)
-QT_CLASS_LIB(QAbstractSocket, QtNetwork, qabstractsocket.h)
-QT_CLASS_LIB(QAuthenticator, QtNetwork, qauthenticator.h)
 QT_CLASS_LIB(QFtp, QtNetwork, qftp.h)
-QT_CLASS_LIB(QIPv6Address, QtNetwork, qhostaddress.h)
-QT_CLASS_LIB(Q_IPV6ADDR, QtNetwork, qhostaddress.h)
-QT_CLASS_LIB(QHostAddress, QtNetwork, qhostaddress.h)
-QT_CLASS_LIB(QHostInfo, QtNetwork, qhostinfo.h)
 QT_CLASS_LIB(QHttpHeader, QtNetwork, qhttp.h)
 QT_CLASS_LIB(QHttpResponseHeader, QtNetwork, qhttp.h)
 QT_CLASS_LIB(QHttpRequestHeader, QtNetwork, qhttp.h)
 QT_CLASS_LIB(QHttp, QtNetwork, qhttp.h)
+QT_CLASS_LIB(QNetworkAccessManager, QtNetwork, qnetworkaccessmanager.h)
+QT_CLASS_LIB(QNetworkCookie, QtNetwork, qnetworkcookie.h)
+QT_CLASS_LIB(QNetworkCookieJar, QtNetwork, qnetworkcookie.h)
+QT_CLASS_LIB(QNetworkReply, QtNetwork, qnetworkreply.h)
+QT_CLASS_LIB(QNetworkRequest, QtNetwork, qnetworkrequest.h)
+QT_CLASS_LIB(QAuthenticator, QtNetwork, qauthenticator.h)
+QT_CLASS_LIB(QIPv6Address, QtNetwork, qhostaddress.h)
+QT_CLASS_LIB(Q_IPV6ADDR, QtNetwork, qhostaddress.h)
+QT_CLASS_LIB(QHostAddress, QtNetwork, qhostaddress.h)
+QT_CLASS_LIB(QHostInfo, QtNetwork, qhostinfo.h)
 QT_CLASS_LIB(QNetworkAddressEntry, QtNetwork, qnetworkinterface.h)
 QT_CLASS_LIB(QNetworkInterface, QtNetwork, qnetworkinterface.h)
 QT_CLASS_LIB(QNetworkProxy, QtNetwork, qnetworkproxy.h)
-QT_CLASS_LIB(QSsl, QtNetwork, qssl.h)
-QT_CLASS_LIB(QSslCertificate, QtNetwork, qsslcertificate.h)
-QT_CLASS_LIB(QSslCipher, QtNetwork, qsslcipher.h)
-QT_CLASS_LIB(QSslError, QtNetwork, qsslerror.h)
-QT_CLASS_LIB(QSslKey, QtNetwork, qsslkey.h)
-QT_CLASS_LIB(QSslSocket, QtNetwork, qsslsocket.h)
+QT_CLASS_LIB(QUrlInfo, QtNetwork, qurlinfo.h)
+QT_CLASS_LIB(QAbstractSocket, QtNetwork, qabstractsocket.h)
+QT_CLASS_LIB(QLocalServer, QtNetwork, qlocalserver.h)
+QT_CLASS_LIB(QLocalSocket, QtNetwork, qlocalsocket.h)
 QT_CLASS_LIB(QTcpServer, QtNetwork, qtcpserver.h)
 QT_CLASS_LIB(QTcpSocket, QtNetwork, qtcpsocket.h)
 QT_CLASS_LIB(QUdpSocket, QtNetwork, qudpsocket.h)
-QT_CLASS_LIB(QUrlInfo, QtNetwork, qurlinfo.h)
+QT_CLASS_LIB(QSsl, QtNetwork, qssl.h)
+QT_CLASS_LIB(QSslCertificate, QtNetwork, qsslcertificate.h)
+QT_CLASS_LIB(QSslCipher, QtNetwork, qsslcipher.h)
+QT_CLASS_LIB(QSslConfiguration, QtNetwork, qsslconfiguration.h)
+QT_CLASS_LIB(QSslError, QtNetwork, qsslerror.h)
+QT_CLASS_LIB(QSslKey, QtNetwork, qsslkey.h)
+QT_CLASS_LIB(QSslSocket, QtNetwork, qsslsocket.h)
+QT_CLASS_LIB(QHelpGlobal, QtHelp, qhelp_global.h)
+QT_CLASS_LIB(QHelpContentItem, QtHelp, qhelpcontentwidget.h)
+QT_CLASS_LIB(QHelpContentModel, QtHelp, qhelpcontentwidget.h)
+QT_CLASS_LIB(QHelpContentWidget, QtHelp, qhelpcontentwidget.h)
+QT_CLASS_LIB(QHelpEngine, QtHelp, qhelpengine.h)
+QT_CLASS_LIB(QHelpEngineCore, QtHelp, qhelpenginecore.h)
+QT_CLASS_LIB(QHelpIndexModel, QtHelp, qhelpindexwidget.h)
+QT_CLASS_LIB(QHelpIndexWidget, QtHelp, qhelpindexwidget.h)
+QT_CLASS_LIB(QHelpSearchQuery, QtHelp, qhelpsearchengine.h)
+QT_CLASS_LIB(QHelpSearchEngine, QtHelp, qhelpsearchengine.h)
+QT_CLASS_LIB(QHelpSearchQueryWidget, QtHelp, qhelpsearchquerywidget.h)
+QT_CLASS_LIB(QHelpSearchResultWidget, QtHelp, qhelpsearchresultwidget.h)
+QT_CLASS_LIB(QAssistantClient, QtAssistant, qassistantclient.h)
+QT_CLASS_LIB(QAbstractMessageHandler, QtXmlPatterns, qabstractmessagehandler.h)
+QT_CLASS_LIB(QAbstractUriResolver, QtXmlPatterns, qabstracturiresolver.h)
+QT_CLASS_LIB(QXmlNodeModelIndex, QtXmlPatterns, qabstractxmlnodemodel.h)
+QT_CLASS_LIB(QAbstractXmlNodeModel, QtXmlPatterns, qabstractxmlnodemodel.h)
+QT_CLASS_LIB(QXmlItem, QtXmlPatterns, qabstractxmlnodemodel.h)
+QT_CLASS_LIB(QAbstractXmlReceiver, QtXmlPatterns, qabstractxmlreceiver.h)
+QT_CLASS_LIB(QSimpleXmlNodeModel, QtXmlPatterns, qsimplexmlnodemodel.h)
+QT_CLASS_LIB(QSourceLocation, QtXmlPatterns, qsourcelocation.h)
+QT_CLASS_LIB(QXmlFormatter, QtXmlPatterns, qxmlformatter.h)
+QT_CLASS_LIB(QXmlName, QtXmlPatterns, qxmlname.h)
+QT_CLASS_LIB(QXmlNamePool, QtXmlPatterns, qxmlnamepool.h)
+QT_CLASS_LIB(QXmlQuery, QtXmlPatterns, qxmlquery.h)
+QT_CLASS_LIB(QXmlResultItems, QtXmlPatterns, qxmlresultitems.h)
+QT_CLASS_LIB(QXmlSerializer, QtXmlPatterns, qxmlserializer.h)
+QT_CLASS_LIB(QWebHitTestResult, QtWebKit, qwebframe.h)
+QT_CLASS_LIB(QWebFrame, QtWebKit, qwebframe.h)
+QT_CLASS_LIB(QWebHistoryItem, QtWebKit, qwebhistory.h)
+QT_CLASS_LIB(QWebHistory, QtWebKit, qwebhistory.h)
+QT_CLASS_LIB(QWebHistoryInterface, QtWebKit, qwebhistoryinterface.h)
+QT_CLASS_LIB(QWebPage, QtWebKit, qwebpage.h)
+QT_CLASS_LIB(QWebPluginFactory, QtWebKit, qwebpluginfactory.h)
+QT_CLASS_LIB(QWebSettings, QtWebKit, qwebsettings.h)
+QT_CLASS_LIB(QWebView, QtWebKit, qwebview.h)
+QT_CLASS_LIB(QSignalSpy, QtTest, qsignalspy.h)
+QT_CLASS_LIB(QTest, QtTest, qtest.h)
+QT_CLASS_LIB(QTestAccessibilityEvent, QtTest, qtestaccessible.h)
+QT_CLASS_LIB(QTestAccessibility, QtTest, qtestaccessible.h)
+QT_CLASS_LIB(QTestData, QtTest, qtestdata.h)
+QT_CLASS_LIB(QTestEvent, QtTest, qtestevent.h)
+QT_CLASS_LIB(QTestKeyEvent, QtTest, qtestevent.h)
+QT_CLASS_LIB(QTestKeyClicksEvent, QtTest, qtestevent.h)
+QT_CLASS_LIB(QTestMouseEvent, QtTest, qtestevent.h)
+QT_CLASS_LIB(QTestDelayEvent, QtTest, qtestevent.h)
+QT_CLASS_LIB(QTestEventList, QtTest, qtestevent.h)
+QT_CLASS_LIB(QTestEventLoop, QtTest, qtesteventloop.h)
+QT_CLASS_LIB(QEventSizeOfChecker, QtTest, qtestspontaneevent.h)
+QT_CLASS_LIB(QEventSizeOfChecker, QtTest, qtestspontaneevent.h)
+QT_CLASS_LIB(QSpontaneKeyEvent, QtTest, qtestspontaneevent.h)
+QT_CLASS_LIB(QDBusAbstractAdaptor, QtDBus, qdbusabstractadaptor.h)
+QT_CLASS_LIB(QDBusAbstractInterface, QtDBus, qdbusabstractinterface.h)
+QT_CLASS_LIB(QDBusArgument, QtDBus, qdbusargument.h)
+QT_CLASS_LIB(QDBusConnection, QtDBus, qdbusconnection.h)
+QT_CLASS_LIB(QDBusConnectionInterface, QtDBus, qdbusconnectioninterface.h)
+QT_CLASS_LIB(QDBusContext, QtDBus, qdbuscontext.h)
+QT_CLASS_LIB(QDBusError, QtDBus, qdbuserror.h)
+QT_CLASS_LIB(QDBusObjectPath, QtDBus, qdbusextratypes.h)
+QT_CLASS_LIB(QDBusSignature, QtDBus, qdbusextratypes.h)
+QT_CLASS_LIB(QDBusVariant, QtDBus, qdbusextratypes.h)
+QT_CLASS_LIB(QDBusInterface, QtDBus, qdbusinterface.h)
+QT_CLASS_LIB(QDBusMessage, QtDBus, qdbusmessage.h)
+QT_CLASS_LIB(QDBusMetaType, QtDBus, qdbusmetatype.h)
+QT_CLASS_LIB(QDBusReply, QtDBus, qdbusreply.h)
+QT_CLASS_LIB(QDBusReply, QtDBus, qdbusreply.h)
+QT_CLASS_LIB(QDBusServer, QtDBus, qdbusserver.h)
+QT_CLASS_LIB(QScriptable, QtScript, qscriptable.h)
+QT_CLASS_LIB(QScriptClass, QtScript, qscriptclass.h)
+QT_CLASS_LIB(QScriptClassPropertyIterator, QtScript, qscriptclasspropertyiterator.h)
+QT_CLASS_LIB(QScriptContext, QtScript, qscriptcontext.h)
+QT_CLASS_LIB(QScriptContextInfo, QtScript, qscriptcontextinfo.h)
+QT_CLASS_LIB(QScriptContextInfoList, QtScript, qscriptcontextinfo.h)
+QT_CLASS_LIB(QScriptEngine, QtScript, qscriptengine.h)
+QT_CLASS_LIB(QScriptEngineAgent, QtScript, qscriptengineagent.h)
+QT_CLASS_LIB(QScriptExtensionInterface, QtScript, qscriptextensioninterface.h)
+QT_CLASS_LIB(QScriptExtensionPlugin, QtScript, qscriptextensionplugin.h)
+QT_CLASS_LIB(QScriptString, QtScript, qscriptstring.h)
+QT_CLASS_LIB(QScriptValueList, QtScript, qscriptvalue.h)
+QT_CLASS_LIB(QScriptValue, QtScript, qscriptvalue.h)
+QT_CLASS_LIB(QScriptValueIterator, QtScript, qscriptvalueiterator.h)
 QT_CLASS_LIB(QSqlDriverCreatorBase, QtSql, qsqldatabase.h)
 QT_CLASS_LIB(QSqlDriverCreator, QtSql, qsqldatabase.h)
 QT_CLASS_LIB(QSqlDatabase, QtSql, qsqldatabase.h)
@@ -345,7 +456,6 @@ QT_CLASS_LIB(QSQLiteResult, QtSql, qsql_sqlite.h)
 QT_CLASS_LIB(QSQLiteDriver, QtSql, qsql_sqlite.h)
 QT_CLASS_LIB(QSQLite2Result, QtSql, qsql_sqlite2.h)
 QT_CLASS_LIB(QSQLite2Driver, QtSql, qsql_sqlite2.h)
-QT_CLASS_LIB(QAssistantClient, QtAssistant, qassistantclient.h)
 QT_CLASS_LIB(QAccessible, QtGui, qaccessible.h)
 QT_CLASS_LIB(QAccessibleInterface, QtGui, qaccessible.h)
 QT_CLASS_LIB(QAccessibleInterfaceEx, QtGui, qaccessible.h)
@@ -372,14 +482,18 @@ QT_CLASS_LIB(QColorDialog, QtGui, qcolordialog.h)
 QT_CLASS_LIB(QDialog, QtGui, qdialog.h)
 QT_CLASS_LIB(QErrorMessage, QtGui, qerrormessage.h)
 QT_CLASS_LIB(QFileDialog, QtGui, qfiledialog.h)
+QT_CLASS_LIB(QFileSystemModel, QtGui, qfilesystemmodel.h)
 QT_CLASS_LIB(QFontDialog, QtGui, qfontdialog.h)
 QT_CLASS_LIB(QInputDialog, QtGui, qinputdialog.h)
 QT_CLASS_LIB(QMessageBox, QtGui, qmessagebox.h)
 QT_CLASS_LIB(QPageSetupDialog, QtGui, qpagesetupdialog.h)
+QT_CLASS_LIB(QUnixPrintWidget, QtGui, qprintdialog.h)
 QT_CLASS_LIB(QPrintDialog, QtGui, qprintdialog.h)
+QT_CLASS_LIB(QPrintPreviewDialog, QtGui, qprintpreviewdialog.h)
 QT_CLASS_LIB(QProgressDialog, QtGui, qprogressdialog.h)
 QT_CLASS_LIB(QWizard, QtGui, qwizard.h)
 QT_CLASS_LIB(QWizardPage, QtGui, qwizard.h)
+QT_CLASS_LIB(QGraphicsGridLayout, QtGui, qgraphicsgridlayout.h)
 QT_CLASS_LIB(QGraphicsItem, QtGui, qgraphicsitem.h)
 QT_CLASS_LIB(QAbstractGraphicsShapeItem, QtGui, qgraphicsitem.h)
 QT_CLASS_LIB(QGraphicsPathItem, QtGui, qgraphicsitem.h)
@@ -392,6 +506,10 @@ QT_CLASS_LIB(QGraphicsTextItem, QtGui, qgraphicsitem.h)
 QT_CLASS_LIB(QGraphicsSimpleTextItem, QtGui, qgraphicsitem.h)
 QT_CLASS_LIB(QGraphicsItemGroup, QtGui, qgraphicsitem.h)
 QT_CLASS_LIB(QGraphicsItemAnimation, QtGui, qgraphicsitemanimation.h)
+QT_CLASS_LIB(QGraphicsLayout, QtGui, qgraphicslayout.h)
+QT_CLASS_LIB(QGraphicsLayoutItem, QtGui, qgraphicslayoutitem.h)
+QT_CLASS_LIB(QGraphicsLinearLayout, QtGui, qgraphicslinearlayout.h)
+QT_CLASS_LIB(QGraphicsProxyWidget, QtGui, qgraphicsproxywidget.h)
 QT_CLASS_LIB(QGraphicsScene, QtGui, qgraphicsscene.h)
 QT_CLASS_LIB(QGraphicsSceneEvent, QtGui, qgraphicssceneevent.h)
 QT_CLASS_LIB(QGraphicsSceneMouseEvent, QtGui, qgraphicssceneevent.h)
@@ -400,7 +518,10 @@ QT_CLASS_LIB(QGraphicsSceneContextMenuEvent, QtGui, qgraphicssceneevent.h)
 QT_CLASS_LIB(QGraphicsSceneHoverEvent, QtGui, qgraphicssceneevent.h)
 QT_CLASS_LIB(QGraphicsSceneHelpEvent, QtGui, qgraphicssceneevent.h)
 QT_CLASS_LIB(QGraphicsSceneDragDropEvent, QtGui, qgraphicssceneevent.h)
+QT_CLASS_LIB(QGraphicsSceneResizeEvent, QtGui, qgraphicssceneevent.h)
+QT_CLASS_LIB(QGraphicsSceneMoveEvent, QtGui, qgraphicssceneevent.h)
 QT_CLASS_LIB(QGraphicsView, QtGui, qgraphicsview.h)
+QT_CLASS_LIB(QGraphicsWidget, QtGui, qgraphicswidget.h)
 QT_CLASS_LIB(QBitmap, QtGui, qbitmap.h)
 QT_CLASS_LIB(QIcon, QtGui, qicon.h)
 QT_CLASS_LIB(QIconSet, QtGui, qicon.h)
@@ -452,6 +573,7 @@ QT_CLASS_LIB(QSortFilterProxyModel, QtGui, qsortfilterproxymodel.h)
 QT_CLASS_LIB(QStandardItem, QtGui, qstandarditemmodel.h)
 QT_CLASS_LIB(QStandardItemModel, QtGui, qstandarditemmodel.h)
 QT_CLASS_LIB(QStringListModel, QtGui, qstringlistmodel.h)
+QT_CLASS_LIB(QStyledItemDelegate, QtGui, qstyleditemdelegate.h)
 QT_CLASS_LIB(QTableView, QtGui, qtableview.h)
 QT_CLASS_LIB(QTableWidgetSelectionRange, QtGui, qtablewidget.h)
 QT_CLASS_LIB(QTableWidgetItem, QtGui, qtablewidget.h)
@@ -505,6 +627,7 @@ QT_CLASS_LIB(QShortcutEvent, QtGui, qevent.h)
 QT_CLASS_LIB(QClipboardEvent, QtGui, qevent.h)
 QT_CLASS_LIB(QWindowStateChangeEvent, QtGui, qevent.h)
 QT_CLASS_LIB(QMenubarUpdatedEvent, QtGui, qevent.h)
+QT_CLASS_LIB(QFormLayout, QtGui, qformlayout.h)
 QT_CLASS_LIB(QGridLayout, QtGui, qgridlayout.h)
 QT_CLASS_LIB(QKeySequence, QtGui, qkeysequence.h)
 QT_CLASS_LIB(QKeySequence, QtGui, qkeysequence.h)
@@ -513,6 +636,7 @@ QT_CLASS_LIB(QLayout, QtGui, qlayout.h)
 QT_CLASS_LIB(QLayoutItem, QtGui, qlayoutitem.h)
 QT_CLASS_LIB(QSpacerItem, QtGui, qlayoutitem.h)
 QT_CLASS_LIB(QWidgetItem, QtGui, qlayoutitem.h)
+QT_CLASS_LIB(QWidgetItemV2, QtGui, qlayoutitem.h)
 QT_CLASS_LIB(QMimeSource, QtGui, qmime.h)
 QT_CLASS_LIB(QWindowsMime, QtGui, qmime.h)
 QT_CLASS_LIB(QMacMime, QtGui, qmime.h)
@@ -559,6 +683,7 @@ QT_CLASS_LIB(QPolygon, QtGui, qpolygon.h)
 QT_CLASS_LIB(QPolygonF, QtGui, qpolygon.h)
 QT_CLASS_LIB(QPrintEngine, QtGui, qprintengine.h)
 QT_CLASS_LIB(QPrinter, QtGui, qprinter.h)
+QT_CLASS_LIB(QPrinterInfo, QtGui, qprinterinfo.h)
 QT_CLASS_LIB(QRegion, QtGui, qregion.h)
 QT_CLASS_LIB(QRgb, QtGui, qrgb.h)
 QT_CLASS_LIB(QStylePainter, QtGui, qstylepainter.h)
@@ -592,6 +717,7 @@ QT_CLASS_LIB(QStyleOptionDockWidgetV2, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleOptionViewItem, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleOptionViewItemV2, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleOptionViewItemV3, QtGui, qstyleoption.h)
+QT_CLASS_LIB(QStyleOptionViewItemV4, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleOptionToolBox, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleOptionToolBoxV2, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleOptionRubberBand, QtGui, qstyleoption.h)
@@ -610,6 +736,8 @@ QT_CLASS_LIB(QStyleHintReturnMask, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleHintReturnVariant, QtGui, qstyleoption.h)
 QT_CLASS_LIB(QStyleFactoryInterface, QtGui, qstyleplugin.h)
 QT_CLASS_LIB(QStylePlugin, QtGui, qstyleplugin.h)
+QT_CLASS_LIB(QWindowsCEStyle, QtGui, qwindowscestyle.h)
+QT_CLASS_LIB(QWindowsMobileStyle, QtGui, qwindowsmobilestyle.h)
 QT_CLASS_LIB(QWindowsStyle, QtGui, qwindowsstyle.h)
 QT_CLASS_LIB(QWindowsVistaStyle, QtGui, qwindowsvistastyle.h)
 QT_CLASS_LIB(QWindowsXPStyle, QtGui, qwindowsxpstyle.h)
@@ -633,6 +761,7 @@ QT_CLASS_LIB(QTextListFormat, QtGui, qtextformat.h)
 QT_CLASS_LIB(QTextImageFormat, QtGui, qtextformat.h)
 QT_CLASS_LIB(QTextFrameFormat, QtGui, qtextformat.h)
 QT_CLASS_LIB(QTextTableFormat, QtGui, qtextformat.h)
+QT_CLASS_LIB(QTextTableCellFormat, QtGui, qtextformat.h)
 QT_CLASS_LIB(QTextInlineObject, QtGui, qtextlayout.h)
 QT_CLASS_LIB(QTextLayout, QtGui, qtextlayout.h)
 QT_CLASS_LIB(QTextLine, QtGui, qtextlayout.h)
@@ -662,6 +791,7 @@ QT_CLASS_LIB(QButtonGroup, QtGui, qbuttongroup.h)
 QT_CLASS_LIB(QCalendarWidget, QtGui, qcalendarwidget.h)
 QT_CLASS_LIB(QCheckBox, QtGui, qcheckbox.h)
 QT_CLASS_LIB(QComboBox, QtGui, qcombobox.h)
+QT_CLASS_LIB(QCommandLinkButton, QtGui, qcommandlinkbutton.h)
 QT_CLASS_LIB(QDateTimeEdit, QtGui, qdatetimeedit.h)
 QT_CLASS_LIB(QTimeEdit, QtGui, qdatetimeedit.h)
 QT_CLASS_LIB(QDateEdit, QtGui, qdatetimeedit.h)
@@ -681,6 +811,9 @@ QT_CLASS_LIB(QMdiSubWindow, QtGui, qmdisubwindow.h)
 QT_CLASS_LIB(QMenu, QtGui, qmenu.h)
 QT_CLASS_LIB(QMenuBar, QtGui, qmenubar.h)
 QT_CLASS_LIB(QMenuItem, QtGui, qmenudata.h)
+QT_CLASS_LIB(QPlainTextEdit, QtGui, qplaintextedit.h)
+QT_CLASS_LIB(QPlainTextDocumentLayout, QtGui, qplaintextedit.h)
+QT_CLASS_LIB(QPrintPreviewWidget, QtGui, qprintpreviewwidget.h)
 QT_CLASS_LIB(QProgressBar, QtGui, qprogressbar.h)
 QT_CLASS_LIB(QPushButton, QtGui, qpushbutton.h)
 QT_CLASS_LIB(QRadioButton, QtGui, qradiobutton.h)
@@ -748,41 +881,10 @@ QT_CLASS_LIB(QDesignerCustomWidgetInterface, QtDesigner, customwidget.h)
 QT_CLASS_LIB(QDesignerCustomWidgetCollectionInterface, QtDesigner, customwidget.h)
 QT_CLASS_LIB(QFormBuilder, QtDesigner, formbuilder.h)
 QT_CLASS_LIB(QDesignerExportWidget, QtDesigner, qdesignerexportwidget.h)
-QT_CLASS_LIB(QSignalSpy, QtTest, qsignalspy.h)
-QT_CLASS_LIB(QTest, QtTest, qtest.h)
-QT_CLASS_LIB(QTestAccessibilityEvent, QtTest, qtestaccessible.h)
-QT_CLASS_LIB(QTestAccessibility, QtTest, qtestaccessible.h)
-QT_CLASS_LIB(QTestData, QtTest, qtestdata.h)
-QT_CLASS_LIB(QTestEvent, QtTest, qtestevent.h)
-QT_CLASS_LIB(QTestKeyEvent, QtTest, qtestevent.h)
-QT_CLASS_LIB(QTestKeyClicksEvent, QtTest, qtestevent.h)
-QT_CLASS_LIB(QTestMouseEvent, QtTest, qtestevent.h)
-QT_CLASS_LIB(QTestDelayEvent, QtTest, qtestevent.h)
-QT_CLASS_LIB(QTestEventList, QtTest, qtestevent.h)
-QT_CLASS_LIB(QTestEventLoop, QtTest, qtesteventloop.h)
-QT_CLASS_LIB(QEventSizeOfChecker, QtTest, qtestspontaneevent.h)
-QT_CLASS_LIB(QEventSizeOfChecker, QtTest, qtestspontaneevent.h)
-QT_CLASS_LIB(QSpontaneKeyEvent, QtTest, qtestspontaneevent.h)
 QT_CLASS_LIB(QGraphicsSvgItem, QtSvg, qgraphicssvgitem.h)
 QT_CLASS_LIB(QSvgGenerator, QtSvg, qsvggenerator.h)
 QT_CLASS_LIB(QSvgRenderer, QtSvg, qsvgrenderer.h)
 QT_CLASS_LIB(QSvgWidget, QtSvg, qsvgwidget.h)
-QT_CLASS_LIB(QDBusAbstractAdaptor, QtDBus, qdbusabstractadaptor.h)
-QT_CLASS_LIB(QDBusAbstractInterface, QtDBus, qdbusabstractinterface.h)
-QT_CLASS_LIB(QDBusArgument, QtDBus, qdbusargument.h)
-QT_CLASS_LIB(QDBusConnection, QtDBus, qdbusconnection.h)
-QT_CLASS_LIB(QDBusConnectionInterface, QtDBus, qdbusconnectioninterface.h)
-QT_CLASS_LIB(QDBusContext, QtDBus, qdbuscontext.h)
-QT_CLASS_LIB(QDBusError, QtDBus, qdbuserror.h)
-QT_CLASS_LIB(QDBusObjectPath, QtDBus, qdbusextratypes.h)
-QT_CLASS_LIB(QDBusSignature, QtDBus, qdbusextratypes.h)
-QT_CLASS_LIB(QDBusVariant, QtDBus, qdbusextratypes.h)
-QT_CLASS_LIB(QDBusInterface, QtDBus, qdbusinterface.h)
-QT_CLASS_LIB(QDBusMessage, QtDBus, qdbusmessage.h)
-QT_CLASS_LIB(QDBusMetaType, QtDBus, qdbusmetatype.h)
-QT_CLASS_LIB(QDBusReply, QtDBus, qdbusreply.h)
-QT_CLASS_LIB(QDBusReply, QtDBus, qdbusreply.h)
-QT_CLASS_LIB(QDBusServer, QtDBus, qdbusserver.h)
 QT_CLASS_LIB(Q3CanvasItemList, Qt3Support, q3canvas.h)
 QT_CLASS_LIB(Q3CanvasItem, Qt3Support, q3canvas.h)
 QT_CLASS_LIB(Q3Canvas, Qt3Support, q3canvas.h)
