@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -138,6 +132,9 @@ public:
     bool isSaveRelative() const                           { return m_saveRelative; }
     void setSaveRelative(bool relative)                   { m_saveRelative = relative; }
     QStringList usedQrcFiles() const                      { return m_usedQrcFiles.keys(); }
+#ifdef OLD_RESOURCE_FORMAT
+    QStringList loadedQrcFiles() const                    { return m_loadedQrcFiles.keys(); } // needed only for loading old resource attribute of <iconset> tag.
+#endif
 
     virtual QVariant loadResource(const QDir &workingDirectory, const DomProperty *icon) const;
 
@@ -153,6 +150,7 @@ private:
     DesignerIconCache    *m_iconCache;
     bool                  m_saveRelative;
     mutable QMap<QString, bool>   m_usedQrcFiles;
+    mutable QMap<QString, bool>   m_loadedQrcFiles;
 };
 
 QDesignerResourceBuilder::QDesignerResourceBuilder(QDesignerFormEditorInterface *core, DesignerPixmapCache *pixmapCache, DesignerIconCache *iconCache) :
@@ -174,8 +172,13 @@ QVariant QDesignerResourceBuilder::loadResource(const QDir &workingDirectory, co
         case DomProperty::Pixmap: {
             PropertySheetPixmapValue pixmap;
             DomResourcePixmap *dp = property->elementPixmap();
-            if (!dp->text().isEmpty())
+            if (!dp->text().isEmpty()) {
                 pixmap.setPath(QFileInfo(workingDirectory, dp->text()).absoluteFilePath());
+#ifdef OLD_RESOURCE_FORMAT
+                if (dp->hasAttributeResource())
+                    m_loadedQrcFiles.insert(QFileInfo(workingDirectory, dp->attributeResource()).absoluteFilePath(), false);
+#endif
+            }
             return qVariantFromValue(pixmap);
         }
 
@@ -202,6 +205,8 @@ QVariant QDesignerResourceBuilder::loadResource(const QDir &workingDirectory, co
             } else {
 #ifdef OLD_RESOURCE_FORMAT
                 setIconPixmap(QIcon::Normal, QIcon::Off, workingDirectory, di->text(), icon);
+                if (di->hasAttributeResource())
+                    m_loadedQrcFiles.insert(QFileInfo(workingDirectory, di->attributeResource()).absoluteFilePath(), false);
 #endif
             }
             return qVariantFromValue(icon);
@@ -723,6 +728,23 @@ QWidget *QDesignerResource::create(DomUI *ui, QWidget *parentWidget)
             // (which might otherwise squeeze the form)
             mainWidget->adjustSize();
         }
+        // Some integration wizards create forms with main containers
+        // based on derived classes of QWidget and load them into Designer
+        // without the plugin existing. This will trigger the auto-promotion
+        // mechanism of Designer, which will set container=false for
+        // QWidgets. For the main container, force container=true and warn.
+        const QDesignerWidgetDataBaseInterface *wdb = core()->widgetDataBase();
+        const int wdbIndex = wdb->indexOfObject(mainWidget);
+        if (wdbIndex != -1) {
+            QDesignerWidgetDataBaseItemInterface *item = wdb->item(wdbIndex);
+            // Promoted main container that is not of container type
+            if (item->isPromoted() && !item->isContainer()) {
+                item->setContainer(true);
+                qWarning("** WARNING The form's main container is an unknown custom widget '%s'."
+                         " Defaulting to a promoted instance of '%s', assuming container.",
+                         item->name().toUtf8().constData(), item->extends().toUtf8().constData());
+            }
+        }
     }
     return mainWidget;
 }
@@ -1988,6 +2010,22 @@ DomProperty *QDesignerResource::createProperty(QObject *object, const QString &p
     return applyProperStdSetAttribute(object, propertyName, QAbstractFormBuilder::createProperty(object, propertyName, value));
 }
 
+QStringList QDesignerResource::mergeWithLoadedPaths(const QStringList &paths) const
+{
+    QStringList newPaths = paths;
+#ifdef OLD_RESOURCE_FORMAT
+    QStringList loadedPaths = m_resourceBuilder->loadedQrcFiles();
+    QStringListIterator it(loadedPaths);
+    while (it.hasNext()) {
+        const QString path = it.next();
+        if (!newPaths.contains(path))
+            newPaths << path;
+    }
+#endif
+    return newPaths;
+}
+
+
 void QDesignerResource::createResources(DomResources *resources)
 {
     QStringList paths;
@@ -2019,6 +2057,11 @@ void QDesignerResource::createResources(DomResources *resources)
             }
         }
     }
+
+#ifdef OLD_RESOURCE_FORMAT
+    paths = mergeWithLoadedPaths(paths);
+#endif
+
     QtResourceSet *resourceSet = m_formWindow->resourceSet();
     if (resourceSet) {
         QStringList oldPaths = resourceSet->activeQrcPaths();
