@@ -1,43 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -52,6 +46,8 @@
 #include <QtCore/QList>
 #include <QtCore/QRect>
 
+QT_BEGIN_NAMESPACE
+
 class QDesignerActions;
 class QDesignerToolWindow;
 class QDesignerFormWindow;
@@ -62,11 +58,13 @@ class QActionGroup;
 class QDockWidget;
 class QMenu;
 class QMenuBar;
+class QMainWindow;
 class QToolBar;
 class QMdiArea;
 class QMdiSubWindow;
 class QCloseEvent;
 class QFont;
+class QtToolBarManager;
 
 class QDesignerFormEditorInterface;
 class QDesignerFormWindowInterface;
@@ -91,8 +89,6 @@ public:
     QDesignerToolWindow *findToolWindow(QWidget *widget) const;
     QDesignerFormWindow *findFormWindow(QWidget *widget) const;
 
-    QDesignerFormWindow *createFormWindow();
-
     QDesignerFormWindow *openForm(const QString &fileName, QString *errorMessage);
     QDesignerFormWindow *openTemplate(const QString &templateFileName,
                                       const QString &editorFileName,
@@ -134,6 +130,7 @@ public slots:
     void setUIMode(UIMode mode);
     void bringAllToFront();
     void toggleFormMinimizationState();
+    void configureToolBars();
 
 // ### private slots:
     void switchToNeutralMode();
@@ -168,6 +165,10 @@ private:
     void setFormWindowMinimized(QDesignerFormWindow *fw, bool minimized);
     void setDesignerUIFont(const QFont &);
 
+    void createToolBarManager(QMainWindow *mw);
+    void removeToolBarManager();
+    void updateToolBarMenu();
+
     QDesignerFormEditorInterface *m_core;
     qdesigner_internal::QDesignerIntegration *m_integration;
 
@@ -188,12 +189,16 @@ private:
     QToolBar *m_editToolBar;
     QToolBar *m_fileToolBar;
 
+    QtToolBarManager *m_toolBarManager;
+
     UIMode m_mode;
 
     QList<QDesignerToolWindow*> m_toolWindows;
     QList<QDesignerFormWindow*> m_formWindows;
 
     QMdiArea *m_mdiArea;
+    QMenu *m_toolbarMenu;
+    QAction *m_configureToolBars;
 
     // Helper class to remember the position of a window while switching user interface modes.
     class Position {
@@ -222,4 +227,6 @@ private:
     State m_state;
 };
 
+QT_END_NAMESPACE
+
 #endif // QDESIGNER_WORKBENCH_H
