@@ -1,36 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -45,6 +46,8 @@
 #include <QtGui/QStyleOption>
 #include "versiondialog.h"
 
+QT_BEGIN_NAMESPACE
+
 class VersionLabel : public QLabel
 {
     Q_OBJECT
@@ -157,10 +160,10 @@ VersionDialog::VersionDialog(QWidget *parent)
 #endif
             )
 {
-    setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint | Qt::MSWindowsFixedSizeDialogHint);
+    setWindowFlags((windowFlags() & ~Qt::WindowContextHelpButtonHint) | Qt::MSWindowsFixedSizeDialogHint);
     QGridLayout *layout = new QGridLayout(this);
-    VersionLabel *label = new VersionLabel(this);
-    QLabel *lbl = new QLabel(this);
+    VersionLabel *label = new VersionLabel;
+    QLabel *lbl = new QLabel;
     QString version = tr("<h3>%1</h3><br/><br/>Version %2");
 #if QT_EDITION == QT_EDITION_OPENSOURCE
     QString open = tr(" Open Source Edition");
@@ -176,8 +179,12 @@ VersionDialog::VersionDialog(QWidget *parent)
                     "Qt is a comprehensive C++ framework for cross-platform application "
                     "development.<br/><br/>"
                     "You need a commercial Qt license for development of proprietary (closed "
-                    "source) applications. Please see <a href=\"http://www.trolltech.com/company/model.html\">http://www.trolltech.com/company/model"
+                    "source) applications. Please see <a href=\"http://trolltech.com/company/about/businessmodel\">http://trolltech.com/company/about/businessmodel"
                     ".html</a> for an overview of Qt licensing.<br/>");
+#elif defined(QT_PRODUCT_LICENSE)
+                    tr("This program is licensed to you under the terms of the "
+                    "Qt %1 License Agreement. For details, see the license file "
+                    "that came with this software distribution.<br/>").arg(QT_PRODUCT_LICENSE);
 #else
                     tr("This program is licensed to you under the terms of the "
                     "Qt Commercial License Agreement. For details, see the file LICENSE "
@@ -186,7 +193,7 @@ VersionDialog::VersionDialog(QWidget *parent)
 
     lbl->setText(tr("%1"
                     "<br/>%2"
-                    "<br/>Copyright 2000-2007 Trolltech ASA. All rights reserved."
+                    "<br/>Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies)."
                     "<br/><br/>The program is provided AS IS with NO WARRANTY OF ANY KIND,"
                     " INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A"
                     " PARTICULAR PURPOSE.<br/> ").arg(version).arg(edition));
@@ -202,4 +209,6 @@ VersionDialog::VersionDialog(QWidget *parent)
     layout->addWidget(buttonBox, 4, 2, 1, 1);
 }
 
+QT_END_NAMESPACE
+
 #include "versiondialog.moc"
