@@ -1,36 +1,37 @@
-/****************************************************************************
+ /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2008 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License versions 2.0 or 3.0 as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file.  Please review the following information
+** to ensure GNU General Public Licensing requirements will be met:
+** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
+** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
+** exception, Nokia gives you certain additional rights. These rights
+** are described in the Nokia Qt GPL Exception version 1.3, included in
+** the file GPL_EXCEPTION.txt in this package.
+**
+** Qt for Windows(R) Licensees
+** As a special exception, Nokia, as the sole copyright holder for Qt
+** Designer, grants users of the Qt/Eclipse Integration plug-in the
+** right for the Qt/Eclipse Integration to link to functionality
+** provided by Qt Designer and its related libraries.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
 **
 ****************************************************************************/
 
@@ -58,10 +59,14 @@ TRANSLATOR qdesigner_internal::Sentinel
 #include <QtGui/QToolBar>
 #include <QtGui/QMenu>
 #include <QtGui/qevent.h>
+#include <QtGui/QApplication>
 #include <QtGui/private/qtoolbarlayout_p.h>
+#include <QtCore/QDebug>
 
 Q_DECLARE_METATYPE(QAction*)
 
+QT_BEGIN_NAMESPACE
+
 namespace {
     typedef QList<QAction*> ActionList;
 }
@@ -77,15 +82,8 @@ void ToolBarEventFilter::install(QToolBar *tb)
 
 ToolBarEventFilter::ToolBarEventFilter(QToolBar *tb) :
     QObject(tb),
-    m_toolBar(tb),
-    m_sentinel(0)
+    m_toolBar(tb)
 {
-    QWidget *w = new QWidget(tb);
-    w->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
-    w->setAttribute(Qt::WA_TransparentForMouseEvents, true);
-    w->setFocusPolicy(Qt::NoFocus);
-    m_sentinel = tb->addWidget(w);
-    tb->addAction(m_sentinel);
 }
 
 bool ToolBarEventFilter::eventFilter (QObject *watched, QEvent *event)
@@ -124,31 +122,40 @@ bool ToolBarEventFilter::eventFilter (QObject *watched, QEvent *event)
     return QObject::eventFilter (watched, event);
 }
 
-int  ToolBarEventFilter::findAction(const QPoint &pos) const
-{
-    // Default to sentinel action if out of geometry
-    const int index = actionIndexAt(m_toolBar, pos);
-    return index == -1 ? 0 : index;
-}
-
 bool ToolBarEventFilter::handleContextMenuEvent(QContextMenuEvent * event )
 {
     event->accept();
 
-    const int index = findAction(m_toolBar->mapFromGlobal(event->globalPos()));
-    QAction *action = m_toolBar->actions().at(index);
+    const QPoint globalPos = event->globalPos();
+    const int index = actionIndexAt(m_toolBar, m_toolBar->mapFromGlobal(globalPos), m_toolBar->orientation());
+    const ActionList actions = m_toolBar->actions();
+    QAction *action = index != -1 ?actions.at(index) : 0;
     QVariant itemData;
-    qVariantSetValue(itemData, action);
-
     QMenu menu(0);
 
-    QAction *newSeperatorAct = menu.addAction(tr("Insert Separator"));
-    newSeperatorAct->setData(itemData);
-    connect(newSeperatorAct, SIGNAL(triggered()), this, SLOT(slotInsertSeparator()));
-    menu.addSeparator();
+    // Insert before
+    if (action && index != 0 && !action->isSeparator()) {
+        QAction *newSeperatorAct = menu.addAction(tr("Insert Separator before '%1'").arg(action->objectName()));
+        qVariantSetValue(itemData, action);
+        newSeperatorAct->setData(itemData);
+        connect(newSeperatorAct, SIGNAL(triggered()), this, SLOT(slotInsertSeparator()));
+    }
 
-    if (action && action != m_sentinel) {
+    // Append separator
+    if (actions.empty() || !actions.back()->isSeparator()) {
+        QAction *newSeperatorAct = menu.addAction(tr("Append Separator"));
+        qVariantSetValue(itemData, static_cast<QAction*>(0));
+        newSeperatorAct->setData(itemData);
+        connect(newSeperatorAct, SIGNAL(triggered()), this, SLOT(slotInsertSeparator()));
+    }
+    // Remove
+    if (!menu.actions().empty())
+        menu.addSeparator();
+
+    // Remove
+    if (action) {
         QAction *a = menu.addAction(tr("Remove action '%1'").arg(action->objectName()));
+        qVariantSetValue(itemData, action);
         a->setData(itemData);
         connect(a, SIGNAL(triggered()), this, SLOT(slotRemoveSelectedAction()));
     }
@@ -156,7 +163,7 @@ bool ToolBarEventFilter::handleContextMenuEvent(QContextMenuEvent * event )
     QAction *remove_toolbar = menu.addAction(tr("Remove Toolbar '%1'").arg(m_toolBar->objectName()));
     connect(remove_toolbar, SIGNAL(triggered()), this, SLOT(slotRemoveToolBar()));
 
-    menu.exec(event->globalPos());
+    menu.exec(globalPos);
     return true;
 }
 
@@ -241,19 +248,6 @@ void ToolBarEventFilter::hideDragIndicator()
     adjustDragIndicator(QPoint(-1, -1));
 }
 
-void ToolBarEventFilter::adjustSpecialActions(QToolBar *tb)
-{
-    if (ToolBarEventFilter *tef = qFindChild<ToolBarEventFilter *>(tb))
-        tef->positionSentinel();
-}
-
-void ToolBarEventFilter::positionSentinel()
-{
-    // Make sure dummy is last
-    m_toolBar->removeAction(m_sentinel);
-    m_toolBar->addAction(m_sentinel);
-}
-
 bool ToolBarEventFilter::handleMousePressEvent(QMouseEvent *event)
 {
     if (event->button() != Qt::LeftButton || withinHandleArea(m_toolBar, event->pos()))
@@ -351,14 +345,24 @@ bool ToolBarEventFilter::handleDropEvent(QDropEvent *event)
         return true;
     }
 
+    // Try to find action to 'insert before'. Click on action or in free area, else ignore.
+    QAction *beforeAction = 0;
+    const QPoint pos = event->pos();
+    const int index = actionIndexAt(m_toolBar, pos, m_toolBar->orientation());
+    if (index != -1) {
+        beforeAction = actions.at(index);
+    } else {
+        if (!freeArea(m_toolBar).contains(pos)) {
+            event->ignore();
+            hideDragIndicator();
+            return true;
+        }
+    }
+
     event->acceptProposedAction();
-
-    int index = findAction(event->pos());
-    index = qMin(index, actions.count() - 1);
-
     QDesignerFormWindowInterface *fw = formWindow();
     InsertActionIntoCommand *cmd = new InsertActionIntoCommand(fw);
-    cmd->init(m_toolBar, action, actions.at(index));
+    cmd->init(m_toolBar, action, beforeAction);
     fw->commandHistory()->push(cmd);
     hideDragIndicator();
     return true;
@@ -366,18 +370,20 @@ bool ToolBarEventFilter::handleDropEvent(QDropEvent *event)
 
 void ToolBarEventFilter::startDrag(const QPoint &pos, Qt::KeyboardModifiers modifiers)
 {
-    const int index = findAction(pos);
-    const ActionList actions = m_toolBar->actions();
-    if (index == actions.count() - 1)
+    const int index = actionIndexAt(m_toolBar, pos, m_toolBar->orientation());
+    if (index == - 1)
         return;
 
+    const ActionList actions = m_toolBar->actions();
     QAction *action = actions.at(index);
     QDesignerFormWindowInterface *fw = formWindow();
 
     const Qt::DropAction dropAction = (modifiers & Qt::ControlModifier) ? Qt::CopyAction : Qt::MoveAction;
     if (dropAction == Qt::MoveAction) {
         RemoveActionFromCommand *cmd = new RemoveActionFromCommand(fw);
-        cmd->init(m_toolBar, action, actions.at(index + 1));
+        const int nextIndex = index + 1;
+        QAction *nextAction = nextIndex < actions.size() ? actions.at(nextIndex) : 0;
+        cmd->init(m_toolBar, action, nextAction);
         fw->commandHistory()->push(cmd);
     }
 
@@ -388,7 +394,10 @@ void ToolBarEventFilter::startDrag(const QPoint &pos, Qt::KeyboardModifiers modi
     if (drag->start(dropAction) == Qt::IgnoreAction) {
         hideDragIndicator();
         if (dropAction == Qt::MoveAction) {
-            QAction *previous = m_toolBar->actions().at(index);
+            const ActionList currentActions = m_toolBar->actions();
+            QAction *previous = 0;
+            if (index >= 0 && index < currentActions.size())
+                previous = currentActions.at(index);
             InsertActionIntoCommand *cmd = new InsertActionIntoCommand(fw);
             cmd->init(m_toolBar, action, previous);
             fw->commandHistory()->push(cmd);
@@ -396,58 +405,50 @@ void ToolBarEventFilter::startDrag(const QPoint &pos, Qt::KeyboardModifiers modi
     }
 }
 
-int ToolBarEventFilter::actionIndexAt(const QToolBar *tb, const QPoint &pos)
-{
-    const ActionList actionList = tb->actions();
-    if (const  int size = actionList.size()) {
-        for (int  i = 0; i < size; i++) {
-            QRect g = tb->actionGeometry(actionList.at(i));
-            g.setTopLeft(QPoint(0, 0));
-            if (g.contains(pos))
-                return i;
-        }
-    }
-    return -1;
-}
-
 QAction *ToolBarEventFilter::actionAt(const QToolBar *tb, const QPoint &pos)
 {
-    const int index = actionIndexAt(tb, pos);
+    const int index = actionIndexAt(tb, pos, tb->orientation());
     if (index == -1)
         return 0;
     return tb->actions().at(index);
 }
 
+QRect ToolBarEventFilter::handleArea(const QToolBar *tb)
+{
+    const QToolBarLayout *tbl = qobject_cast<QToolBarLayout *>(tb->layout());
+    Q_ASSERT(tbl);
+    return tbl->handleRect();
+}
+
 bool ToolBarEventFilter::withinHandleArea(const QToolBar *tb, const QPoint &pos)
 {
-    if (QToolBarLayout *tbl = qobject_cast<QToolBarLayout *>(tb->layout()))
-        return tbl->handleRect().contains(pos);
-    return false;
+    return handleArea(tb).contains(pos);
 }
 
-// ------------------- SentinelAction
-
-SentinelAction::SentinelAction(QWidget *widget)
-    : QAction(widget)
+// Determine the free area behind the last action.
+QRect ToolBarEventFilter::freeArea(const QToolBar *tb)
 {
-    setSeparator(true);
+    QRect rc = QRect(QPoint(0, 0), tb->size());
+    const ActionList actionList = tb->actions();
+    QRect exclusionRectangle = actionList.empty() ? handleArea(tb) : tb->actionGeometry(actionList.back());
+    switch (tb->orientation()) {
+    case Qt::Horizontal:
+        switch (QApplication::layoutDirection()) {
+        case Qt::LeftToRight:
+            rc.setX(exclusionRectangle.right() + 1);
+            break;
+        case Qt::RightToLeft:
+            rc.setRight(exclusionRectangle.x());
+            break;
+        }
+        break;
+    case Qt::Vertical:
+        rc.setY(exclusionRectangle.bottom() + 1);
+        break;
+    }
+    return rc;
 }
 
-SentinelAction::~SentinelAction()
-{
 }
 
-// ------------------- Sentinel
-Sentinel::Sentinel(QWidget *widget)
-    : QToolButton(widget)
-{
-    setObjectName(QString::fromUtf8("__qt__passive_new"));
-    setText(QLatin1String(">>"));
-    setToolButtonStyle(Qt::ToolButtonTextOnly);
-    setToolTip(tr("New Tool Bar"));
-}
-
-Sentinel::~Sentinel()
-{
-}
-}
+QT_END_NAMESPACE
